(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     94762,       2325]
NotebookOptionsPosition[     66980,       1649]
NotebookOutlinePosition[     91679,       2222]
CellTagsIndexPosition[     91636,       2219]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Maxwell Equation", "Title",
 CellChangeTimes->{{3.753095286161633*^9, 3.753095287559928*^9}, {
  3.7653000603160677`*^9, 3.765300065840293*^9}}],

Cell[CellGroupData[{

Cell["Initialization", "Section",
 CellChangeTimes->{{3.7530953033017855`*^9, 3.7530953157046394`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"<<", "QuantumAlgebra`"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.7464441987103815`*^9, 3.746444236622961*^9}, {
  3.7467845915842257`*^9, 3.7467846033962855`*^9}, {3.746784661775163*^9, 
  3.746784664075014*^9}}],

Cell[CellGroupData[{

Cell[BoxData["\<\"Application Quantum Algebra by Juergen Habelt\"\>"], "Print",
 CellChangeTimes->CompressedData["
1:eJwd03s41FkYB/ApYt2mTNgWW2hSTcWUpCaDX0RL2QiVtSptu2tyS7SNrBSG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  "]],

Cell[BoxData["\<\"This package is based on the work of Cesar Guerra \
G.,\"\>"], "Print",
 CellChangeTimes->CompressedData["
1:eJwd03s41FkYB/DZiNxmM2FbbKFJNRVTkpoMfhFF2QiVtdq07WZyS1QjWS2G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  "]],

Cell[BoxData["\<\"who developed the original package for Mathematica \
4.1/4.2\"\>"], "Print",
 CellChangeTimes->CompressedData["
1:eJwd03881HccB/Arv/LrlgtrWKFLdRVXkrocvhGNsgiVmZZqm8uvROtk0nBM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  "]],

Cell[BoxData["\<\"For proper styling you should invoke SetNotebookStyles \
once.\"\>"], "Print",
 CellChangeTimes->CompressedData["
1:eJwd03s81WccB/Cz3OZ2lhPWsHI5qU7ilKRODn4RjbIIlZmWauXklmgdmTQc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  "]],

Cell[BoxData["\<\"ALIASES:\\nESC op(du) ESC - Operator with or without \
indices\\nESC hop(du) ESC - Hermitian Operator with or without indices\\nESC \
ket(du) ESC - Ket with or without indices\\nESC (du)bra ESC - Bra with or \
without indices\\nESC (du)braket(du) ESC - BraKet with (left and / or right) \
subscript(s) and / or superscript(s).\\nLetters in parenthesis signify \
optional indices (u - up, d - down) and must be given in that \
order.\\nExample: use opd for an Operator with lower index.\"\>"], "Print",
 CellChangeTimes->CompressedData["
1:eJwd03881HccB/BbxPy65cIaVuhSXcWVUJfDN6JRFqEy01KtXH510TqZNByT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  "]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Problems", "Section",
 CellChangeTimes->{{3.765084024850484*^9, 3.765084029889999*^9}}],

Cell[CellGroupData[{

Cell["\<\
Certain operations are opponents of each other -> problem if used \
automatically\
\>", "ItemNumbered",
 CellChangeTimes->{{3.765084087946722*^9, 3.7650841407633977`*^9}, {
  3.7650992612456226`*^9, 3.7650992858690834`*^9}, {3.765109003918614*^9, 
  3.7651090269144745`*^9}, {3.7950635810017667`*^9, 3.795063617631888*^9}}],

Cell["\<\
Notation with QASimplescript: Implementation solves power problem\
\>", "ItemNumbered",
 CellChangeTimes->{{3.765084087946722*^9, 3.7650843110189657`*^9}, {
  3.7650992913529243`*^9, 3.765099291353916*^9}, {3.7651090683706026`*^9, 
  3.7651090959837413`*^9}, {3.795011605503235*^9, 3.7950116460478563`*^9}}],

Cell["DistributionLaw: Implementation does to change exponents", \
"ItemNumbered",
 CellChangeTimes->{{3.765084087946722*^9, 3.7650843110189657`*^9}, {
  3.765099294117523*^9, 3.7650993257808547`*^9}, {3.7651091167790794`*^9, 
  3.7651091546040864`*^9}, {3.795011568662716*^9, 3.7950115940229445`*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Rules", "Section",
 CellChangeTimes->{{3.7530953316250696`*^9, 3.7530953324568453`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Metric", ",", " ", 
    RowBox[{
     RowBox[{
     "used", " ", "for", " ", "calculations", " ", "with", " ", "co"}], "-", 
     " ", 
     RowBox[{"and", " ", "contravariant", " ", "components"}]}]}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    SubscriptBox["g", 
     RowBox[{"\[Mu]_", ",", "\[Nu]_"}]], ":=", 
    RowBox[{"Piecewise", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1", ",", 
          RowBox[{"\[Mu]", "\[Equal]", "\[Nu]", "\[Equal]", "0"}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", 
          RowBox[{"\[Mu]", "\[Equal]", "\[Nu]"}]}], "}"}]}], "}"}], ",", 
      "0"}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"\[Mu]_", ",", "\[Nu]_"}]], ":=", 
    RowBox[{"Piecewise", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1", ",", 
          RowBox[{"\[Mu]", "\[Equal]", "\[Nu]", "\[Equal]", "0"}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", 
          RowBox[{"\[Mu]", "\[Equal]", "\[Nu]"}]}], "}"}]}], "}"}], ",", 
      "0"}], "]"}]}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.7531806315641794`*^9, 3.753180813885485*^9}, {
  3.753180868392724*^9, 3.7531809237755814`*^9}, {3.753181032701586*^9, 
  3.753181079309929*^9}, {3.7642321886778216`*^9, 3.764232292932061*^9}, {
  3.7650943246584063`*^9, 3.765094350330728*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Looks", " ", "as", " ", "follows", " ", "when", " ", "using", " ", "the", 
    " ", "module", " ", "implementation"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"QASelectDefault", "[", "\"\<Vectors\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"QASetIndexCharacter", "[", 
     RowBox[{"{", 
      RowBox[{"\"\<Mixed\>\"", ",", 
       RowBox[{"{", "}"}]}], "}"}], "]"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"QAResetExplicitIntegrationVariables", "[", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"QAAddExplicitIntegrationVariables", "[", 
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["k", "0"], ",", " ", 
       SubscriptBox["k1", "0"]}], "}"}], "]"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"QAResetAssumptions", "[", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"QAAddAssumptions", "[", 
     RowBox[{"Map", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"#", "\[Element]", "Reals"}], "&"}], ",", 
       RowBox[{"Table", "[", " ", 
        RowBox[{
         SubscriptBox["k", "i"], " ", ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "0", ",", "3"}], "}"}]}], "]"}]}], "]"}], "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"QAAddAssumptions", "[", 
     RowBox[{"Map", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"#", "\[Element]", "Reals"}], "&"}], ",", 
       RowBox[{"Table", "[", " ", 
        RowBox[{
         SubscriptBox["k1", "i"], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "0", ",", "3"}], "}"}]}], "]"}]}], "]"}], "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"QAAddAssumptions", "[", 
     RowBox[{"Map", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"#", "\[Element]", "Reals"}], "&"}], ",", 
       RowBox[{"Table", "[", " ", 
        RowBox[{
         SuperscriptBox["x", "i"], " ", ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "0", ",", "3"}], "}"}]}], "]"}]}], "]"}], "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"QAAddAssumptions", "[", 
     RowBox[{"Map", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"#", "\[Element]", "Reals"}], "&"}], ",", 
       RowBox[{"{", 
        RowBox[{"V", ",", "q"}], "}"}]}], "]"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"QAAddAssumptions", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["k", "0"], "\[GreaterEqual]", "0"}], ",", 
       RowBox[{
        SubscriptBox["k1", "0"], "\[GreaterEqual]", "0"}], ",", " ", 
       RowBox[{"V", "\[GreaterEqual]", "0"}]}], "}"}], "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"rule", "[", 
     RowBox[{"r_", ",", "s_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubsuperscriptBox["\[Epsilon]", 
        RowBox[{
         SubscriptBox["k_", "1"], ",", 
         SubscriptBox["k_", "2"], ",", 
         SubscriptBox["k_", "3"]}], 
        RowBox[{"0", ",", "r"}]], "*", 
       SubsuperscriptBox["\[Epsilon]", 
        RowBox[{
         SubscriptBox["k_", "1"], ",", 
         SubscriptBox["k_", "2"], ",", 
         SubscriptBox["k_", "3"]}], 
        RowBox[{"0", ",", "s"}]]}], ")"}], "\[RuleDelayed]", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"r", "\[Equal]", "0"}], ",", 
           RowBox[{"-", "1"}], ",", 
           RowBox[{"+", "1"}]}], "]"}]}], "*", 
        RowBox[{"KroneckerDelta", "[", 
         RowBox[{"r", ",", "s"}], "]"}]}], "+", 
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"i", "=", "1"}], "3"], 
        RowBox[{"(", 
         RowBox[{
          SubsuperscriptBox["\[Epsilon]", 
           RowBox[{
            SubscriptBox["k", "1"], ",", 
            SubscriptBox["k", "2"], ",", 
            SubscriptBox["k", "3"]}], 
           RowBox[{"i", ",", "r"}]], "*", 
          SubsuperscriptBox["\[Epsilon]", 
           RowBox[{
            SubscriptBox["k", "1"], ",", 
            SubscriptBox["k", "2"], ",", 
            SubscriptBox["k", "3"]}], 
           RowBox[{"i", ",", "s"}]]}], ")"}]}]}], ")"}]}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"QAAddReplacementRules", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"rule", "[", 
         RowBox[{"i", ",", "j"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "0", ",", "i"}], "}"}]}], "]"}], "//", "Flatten"}],
      "]"}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"QAAddReplacementRules", "[", 
     RowBox[{
      RowBox[{"{", " ", 
       RowBox[{
        RowBox[{"DefineNameOrderingRule", "[", "False", "]"}], ",", 
        RowBox[{"DefineCommutatorRule", "[", 
         RowBox[{"False", ",", "True", ",", "True"}], "]"}]}], "}"}], ",", 
      "\"\<CommutatorLocal\>\""}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"QAAddReplacementRules", "[", 
     RowBox[{
      RowBox[{"{", " ", 
       RowBox[{
        RowBox[{"DefineNameOrderingRule", "[", "False", "]"}], ",", 
        RowBox[{"DefineCommutatorRule", "[", 
         RowBox[{"False", ",", "True", ",", "False"}], "]"}]}], "}"}], ",", 
      "\"\<CommutatorReverseLocal\>\""}], "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.748970308237199*^9, 3.7489703878332844`*^9}, {
   3.7489704228220263`*^9, 3.7489704701583986`*^9}, 3.748970505174759*^9, 
   3.7489706999186296`*^9, {3.7489713455338335`*^9, 3.7489714433490677`*^9}, {
   3.7489715074835024`*^9, 3.7489715207165184`*^9}, {3.749012846909777*^9, 
   3.749012872213085*^9}, {3.7490384008539915`*^9, 3.749038475563145*^9}, {
   3.749038552595388*^9, 3.749038565637499*^9}, {3.7505949912854013`*^9, 
   3.7505950665186987`*^9}, {3.75060533266099*^9, 3.7506053386679497`*^9}, {
   3.750605374858466*^9, 3.750605379331471*^9}, {3.750605416585587*^9, 
   3.7506054252783766`*^9}, {3.750605602976101*^9, 3.7506056339863353`*^9}, {
   3.7507650100213957`*^9, 3.75076506169322*^9}, 3.75076619430978*^9, 
   3.75078655421354*^9, {3.753095519103619*^9, 3.753095520660427*^9}, {
   3.7530967603660183`*^9, 3.7530967613036656`*^9}, {3.7531881011524467`*^9, 
   3.753188154594534*^9}, {3.7531882606797504`*^9, 3.753188300619973*^9}, {
   3.75318838666881*^9, 3.7531885418730392`*^9}, {3.7531886609904575`*^9, 
   3.7531887033045917`*^9}, 3.7634622371455483`*^9, {3.7634627113551455`*^9, 
   3.7634627150981383`*^9}, {3.7634691901636467`*^9, 3.7634692118327427`*^9}, 
   3.763469257008788*^9, {3.763469307872674*^9, 3.763469351185894*^9}, {
   3.7634693859230337`*^9, 3.763469434597416*^9}, {3.7634694774338775`*^9, 
   3.7634694882130594`*^9}, {3.7634695292742805`*^9, 3.763469614839528*^9}, {
   3.7634698690413604`*^9, 3.7634698879946847`*^9}, {3.763470143659425*^9, 
   3.7634702109255543`*^9}, {3.7634709903575287`*^9, 
   3.7634709934313016`*^9}, {3.763471561819458*^9, 3.7634715837129235`*^9}, {
   3.7634717213093615`*^9, 3.763471724058016*^9}, {3.7634719604944644`*^9, 
   3.76347202417523*^9}, 3.763474251712321*^9, {3.76347433965926*^9, 
   3.7634743625710015`*^9}, {3.763474403518524*^9, 3.7634744141620646`*^9}, {
   3.7636352373924255`*^9, 3.76363524102275*^9}, {3.7636406614000688`*^9, 
   3.7636406938734326`*^9}, 3.763645541646773*^9, {3.7636462330927*^9, 
   3.7636462962422333`*^9}, {3.763701092027913*^9, 3.7637011277234783`*^9}, {
   3.7642314425544767`*^9, 3.764231596129636*^9}, {3.7642316741903806`*^9, 
   3.7642317133117294`*^9}, {3.7642317930364904`*^9, 
   3.7642318844219875`*^9}, {3.7642377661349087`*^9, 3.764237770885201*^9}, {
   3.764237816147149*^9, 3.7642378709996567`*^9}, {3.7642379028315997`*^9, 
   3.764238038626336*^9}, {3.764762947131156*^9, 3.764762994299947*^9}, {
   3.764763030242834*^9, 3.764763031440624*^9}, {3.7647630877040854`*^9, 
   3.7647631664613943`*^9}, {3.764763198655275*^9, 3.764763201393979*^9}, {
   3.7647633219803877`*^9, 3.764763341507127*^9}, 3.764763422963234*^9, 
   3.764846331134133*^9, {3.7688837153544416`*^9, 3.7688837437644377`*^9}, {
   3.768883803375267*^9, 3.768883911013529*^9}, {3.7688870538206377`*^9, 
   3.7688870736904755`*^9}, {3.768907634333249*^9, 3.7689077510290966`*^9}, {
   3.7692314505305705`*^9, 3.769231463381192*^9}, {3.7956092125586243`*^9, 
   3.7956092198191853`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"QAAddReplacementRules", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         SubscriptBox["k_", "1"], "^", "2"}], "+", 
        RowBox[{
         SubscriptBox["k_", "2"], "^", "2"}], "+", 
        RowBox[{
         SubscriptBox["k_", "3"], "^", "2"}]}], "\[RuleDelayed]", 
       RowBox[{
        SubscriptBox["k", "0"], "^", "2"}]}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          SubscriptBox["k_", "1"], "^", "2"}]}], "-", 
        RowBox[{
         SubscriptBox["k_", "2"], "^", "2"}], "-", 
        RowBox[{
         SubscriptBox["k_", "3"], "^", "2"}]}], "\[RuleDelayed]", 
       RowBox[{"-", 
        RowBox[{
         SubscriptBox["k", "0"], "^", "2"}]}]}]}], "}"}], "]"}], ";"}], 
  " "}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.7634609267462626`*^9, 3.763460934141495*^9}, {
   3.76346097380542*^9, 3.76346097737188*^9}, {3.7634610236142745`*^9, 
   3.763461081481556*^9}, 3.763461113619601*^9, {3.763470002824666*^9, 
   3.763470017683225*^9}, {3.7642320359656177`*^9, 3.764232064666813*^9}, {
   3.7688840616816053`*^9, 3.768884183248418*^9}, {3.769088712816906*^9, 
   3.769088724427804*^9}, {3.7690908983639374`*^9, 3.7690909308121405`*^9}, {
   3.7942308177977047`*^9, 3.794230817976231*^9}, {3.7942874777816153`*^9, 
   3.794287496854618*^9}, 3.79514799591633*^9}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"QAAddReplacementRules", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["k_", "0"], "^", "2"}], "\[RuleDelayed]", 
      RowBox[{
       RowBox[{
        SubscriptBox["k", "1"], "^", "2"}], "+", 
       RowBox[{
        SubscriptBox["k", "2"], "^", "2"}], "+", 
       RowBox[{
        SubscriptBox["k", "3"], "^", "2"}]}]}], "}"}], "]"}], ";"}], " ", 
  "*)"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.7634621407951145`*^9, 3.763462160013775*^9}, {
  3.7634700888529572`*^9, 3.7634701012827053`*^9}, {3.764231964403028*^9, 
  3.764232001487852*^9}, {3.7688842181281347`*^9, 3.768884260465473*^9}, {
  3.7690888712570066`*^9, 3.7690888970709496`*^9}, {3.794226848356415*^9, 
  3.794226852824474*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"QAIntegrate", "[", 
   RowBox[{
    RowBox[{"QAIntegrate", "[", 
     RowBox[{"exp_", ",", "areai_", ",", "ni_Integer", ",", 
      RowBox[{"Sequence", "[", 
       RowBox[{"ivar1_", ",", "ivar2_"}], "]"}]}], "]"}], ",", "areao_", ",", 
    "no_Integer", ",", "ivaro_"}], "]"}], ":=", 
  RowBox[{"QAIntegrate", "[", 
   RowBox[{
    RowBox[{"QAIntegrate", "[", 
     RowBox[{"exp", ",", "areao", ",", "no", ",", "ivaro"}], "]"}], ",", 
    "areai", ",", "ni", ",", "ivar1", ",", "ivar2"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.7633910818789577`*^9, 3.7633911080403156`*^9}, 
   3.763391146228181*^9, {3.7633911988744507`*^9, 3.7633912335208282`*^9}, {
   3.763391273001235*^9, 3.763391389238452*^9}, {3.76339158183239*^9, 
   3.7633917414245663`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"It", " ", "seems"}], ",", " ", 
    RowBox[{
    "every", " ", "notebook", " ", "must", " ", "use", " ", "its", " ", "own",
      " ", "set", " ", "and", " ", "order", " ", "of", " ", "rules"}]}], 
   "\[IndentingNewLine]", "*)"}], "\n", 
  RowBox[{
   RowBox[{"QAEvaluate2", "[", "ex_", "]"}], ":=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{"ex", "//", 
                   RowBox[{"QAReplace", "[", "\"\<IntegrateJoin\>\"", "]"}]}],
                   "//", 
                  RowBox[{
                  "QAReplaceRepeated", "[", "\"\<CommutatorLocal\>\"", 
                   "]"}]}], "//", 
                 RowBox[{
                 "QAReplaceRepeated", "[", "\"\<IntegrateSplit\>\"", "]"}]}], 
                "//", 
                RowBox[{
                "QAReplaceRepeated", "[", "\"\<FullDistributionLaw\>\"", 
                 "]"}]}], "//", 
               RowBox[{"QAReplace", "[", "\"\<IntegrateJoin\>\"", "]"}]}], "//", 
              RowBox[{
              "QAReplaceRepeated", "[", "\"\<FullDistributionLaw\>\"", 
               "]"}]}], "//", 
             RowBox[{
              RowBox[{"Factorise", "[", 
               RowBox[{"#", ",", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"Power", "[", 
                   RowBox[{"E", ",", "_"}], "]"}], ",", 
                  SubscriptBox["k", "_"]}], "}"}]}], "]"}], "&"}]}], "//", 
            RowBox[{"QAReplace", "[", "\"\<CommutatorLocal\>\"", "]"}]}], "//", 
           RowBox[{"QAReplaceRepeated", "[", "\"\<Vectors\>\"", "]"}]}], "//", 
          RowBox[{"QAReplaceRepeated", "[", "\"\<IntegrateSplit\>\"", "]"}]}],
          "//", 
         RowBox[{
         "QAReplaceRepeated", "[", "\"\<FullDistributionLaw\>\"", "]"}]}], "//",
         "QASniff"}], "//", 
       RowBox[{"QAReplace", "[", "\"\<IntegrateJoin\>\"", "]"}]}], "//", 
      RowBox[{"QASimplify", "[", "]"}]}], "//", 
     RowBox[{"QAReplaceRepeated", "[", "\"\<Vectors\>\"", "]"}]}], "//", 
    RowBox[{"QASimplify", "[", "]"}]}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.7637035815381756`*^9, 3.7637036018847747`*^9}, {
   3.763704904657044*^9, 3.7637049159857545`*^9}, {3.7637051179647317`*^9, 
   3.7637051478099337`*^9}, 3.7644978929225388`*^9, 3.764498523973798*^9, {
   3.764590507103718*^9, 3.764590509133288*^9}, {3.7647647306959257`*^9, 
   3.764764741831143*^9}, {3.764764775899622*^9, 3.764764856657626*^9}, {
   3.764765167491832*^9, 3.7647651697448053`*^9}, {3.7652989764624968`*^9, 
   3.765298980615385*^9}, 3.765299520942945*^9, {3.768908254005891*^9, 
   3.768908289339499*^9}, 3.76890832500704*^9, {3.769091088445283*^9, 
   3.769091109565817*^9}, 3.7692314885708375`*^9, {3.79481542089876*^9, 
   3.794815489385684*^9}, {3.7948158576602683`*^9, 3.7948158782442107`*^9}, {
   3.794978893331396*^9, 3.7949788960351706`*^9}, 3.7949789279715405`*^9, {
   3.7949908963705144`*^9, 3.7949908985367603`*^9}, {3.7949917135598745`*^9, 
   3.7949917208334293`*^9}, 3.7949917581227503`*^9, {3.7950105142178497`*^9, 
   3.7950105240685196`*^9}, 3.7950107986754613`*^9, 3.7950109406916513`*^9, {
   3.7950111056497245`*^9, 3.795011109926264*^9}, {3.7950608666447506`*^9, 
   3.7950608711237774`*^9}, {3.7950614641474223`*^9, 3.795061480111747*^9}, 
   3.7950621337602262`*^9, {3.7950636677000093`*^9, 3.7950636867630568`*^9}, 
   3.7950650011363583`*^9, {3.795087829666307*^9, 3.795087849365649*^9}, {
   3.7950884666459627`*^9, 3.7950884691432867`*^9}, 3.7950888343625402`*^9, {
   3.79509086573079*^9, 3.795090873330511*^9}, 3.7950909140297394`*^9, {
   3.7950990486376777`*^9, 3.795099060943731*^9}, 3.795099385808359*^9, {
   3.795609281279196*^9, 3.795609293485593*^9}, 3.795611290355302*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Application in QFT - Vectors", "Section",
 CellChangeTimes->{{3.7530956616393967`*^9, 3.753095675373624*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Define", " ", "the", " ", "exponent", " ", "of", " ", "wave", " ", 
    "function", " ", "solutions"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"exp", ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", "}"}], ",", 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         SubscriptBox["k", "i"], " ", 
         SuperscriptBox["x", "i"]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "3"}], "}"}]}], "]"}]}], "]"}]}], "\n", 
   RowBox[{"(*", " ", 
    RowBox[{"The", " ", "Electromagnetic", " ", "Field", " ", 
     RowBox[{"(", 
      RowBox[{"Vector", " ", "Field"}], ")"}]}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"A", "[", "\[Mu]_", "]"}], ":=", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Integral]", "\[Infinity]"], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"1", "/", 
          RowBox[{"Sqrt", "[", 
           RowBox[{"2", " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"2", " ", "\[Pi]"}], ")"}], "^", "3"}], " ", 
            SubscriptBox["k", "0"]}], "]"}]}], " ", 
         RowBox[{
          UnderoverscriptBox["\[Sum]", 
           RowBox[{"r", "=", "0"}], "3"], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SubsuperscriptBox["\[Epsilon]", 
              RowBox[{
               SubscriptBox["k", "1"], ",", 
               SubscriptBox["k", "2"], ",", 
               SubscriptBox["k", "3"]}], 
              RowBox[{"\[Mu]", ",", "r"}]], " ", 
             SubsuperscriptBox[
              OverscriptBox["a", "^"], 
              RowBox[{
               SubscriptBox["k", "1"], ",", 
               SubscriptBox["k", "2"], ",", 
               SubscriptBox["k", "3"]}], "r"]}], ")"}], " ", 
           RowBox[{"Exp", "[", 
            RowBox[{
             RowBox[{"-", "\[ImaginaryI]"}], " ", "exp"}], "]"}]}]}]}], ")"}], 
       RowBox[{
        SuperscriptBox["\[DifferentialD]", "3"], "k"}]}]}], "+", 
     RowBox[{
      SubscriptBox["\[Integral]", "\[Infinity]"], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"1", "/", 
          RowBox[{"Sqrt", "[", 
           RowBox[{"2", " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"2", " ", "\[Pi]"}], ")"}], "^", "3"}], " ", 
            SubscriptBox["k", "0"]}], "]"}]}], " ", 
         RowBox[{
          UnderoverscriptBox["\[Sum]", 
           RowBox[{"r", "=", "0"}], "3"], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SubsuperscriptBox["\[Epsilon]", 
              RowBox[{
               SubscriptBox["k", "1"], ",", 
               SubscriptBox["k", "2"], ",", 
               SubscriptBox["k", "3"]}], 
              RowBox[{"\[Mu]", ",", "r"}]], " ", 
             SubsuperscriptBox[
              OverscriptBox["a", "^"], 
              RowBox[{
               SubscriptBox["k", "1"], ",", 
               SubscriptBox["k", "2"], ",", 
               SubscriptBox["k", "3"]}], 
              RowBox[{"r", ",", "\[Dagger]"}]]}], ")"}], " ", 
           RowBox[{"Exp", "[", 
            RowBox[{"\[ImaginaryI]", " ", "exp"}], "]"}]}]}]}], ")"}], 
       RowBox[{
        SuperscriptBox["\[DifferentialD]", "3"], "k"}]}]}]}]}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.746790561237116*^9, 3.746790579017577*^9}, {
   3.746790624828087*^9, 3.7467906832289424`*^9}, {3.7467910806134157`*^9, 
   3.746791097648903*^9}, {3.7467912451504765`*^9, 3.746791359024001*^9}, {
   3.7472853208397675`*^9, 3.747285355043347*^9}, {3.764232474317463*^9, 
   3.7642324930264125`*^9}, 3.7642340791524296`*^9, {3.76440305526606*^9, 
   3.7644030850154767`*^9}, {3.7688842971582737`*^9, 3.768884338894638*^9}, {
   3.7688843836788282`*^9, 3.7688844051463823`*^9}, {3.7688845498942027`*^9, 
   3.7688846516798677`*^9}, {3.795608804427352*^9, 3.795608808907378*^9}}],

Cell[CellGroupData[{

Cell["Hamiltonian", "Subsection",
 CellChangeTimes->{{3.753181189848268*^9, 3.753181193541355*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"deriv0", "[", 
   RowBox[{"\[Mu]_", ",", "\[Nu]_"}], "]"}], ":=", 
  RowBox[{
   SubscriptBox["\[GothicCapitalD]", 
    SuperscriptBox["x", "\[Nu]"]], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"A", "[", "\[Mu]", "]"}], "//", "Evaluate"}], 
    ")"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"deriv1", "[", 
   RowBox[{"\[Mu]_", ",", "\[Nu]_"}], "]"}], ":=", 
  RowBox[{"Sum", "[", 
   RowBox[{
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"\[Nu]", ",", "\[Rho]"}]], " ", 
     RowBox[{"deriv0", "[", 
      RowBox[{"\[Mu]", ",", "\[Rho]"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"\[Rho]", ",", "0", ",", "3"}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"deriv2", "[", 
   RowBox[{"\[Mu]_", ",", "\[Nu]_"}], "]"}], ":=", 
  RowBox[{"Sum", "[", 
   RowBox[{
    RowBox[{
     SubscriptBox["g", 
      RowBox[{"\[Mu]", ",", "\[Tau]"}]], " ", 
     RowBox[{"deriv1", "[", 
      RowBox[{"\[Tau]", ",", "\[Nu]"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"\[Tau]", ",", "0", ",", "3"}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"\[GothicCapitalH]", ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "1"}], "/", "2"}], " ", 
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"deriv2", "[", 
       RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], "\[CenterDot]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"deriv1", "[", 
         RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], "/.", 
        RowBox[{"k", "\[Rule]", "k1"}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Mu]", ",", "0", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Nu]", ",", "0", ",", "3"}], "}"}]}], 
    "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"H", ":=", 
  RowBox[{
   SubscriptBox["\[Integral]", "\[Infinity]"], 
   RowBox[{"\[GothicCapitalH]", 
    RowBox[{
     SuperscriptBox["\[DifferentialD]", "3"], "x"}]}]}]}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQA2IQHfTOk23Bt9eOBtFZYDri1DIFEN2mna8OohtOCxqD
6LQHh0xAtFGFozWIZon+bAeiEyKKXED0I5tKMF1196gniF7kfNYHTEeGBYLo
ikzLEBB97HdMFFh/xsdoEK30/GoSiN6a86kSRNdNW9cEtt8mrxdEX+vbOBtE
ezvZzQXRFtx/V4HolYERq0G0XUHvFhAt4p+xFWzfd9GjINqtNQpMb8h5mlP4
/bXjpL23c0H0q+nZ8q3cbxzX3+9RB9FRfA8MQbTCy7smIDqpd+3ktUD6z8zM
qSCaLUN04xYgHSNrvhlEf3s3+wuINrj94CuIPhDh/h9E8y2+wLQVSJ/a8Gpe
j/sbxyP3Ts4H0QBAOMak
  "]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"QAOptions", "[", 
  RowBox[{
   RowBox[{"Verbosity", "\[Rule]", "1"}], ",", 
   RowBox[{"MaxLines", "\[Rule]", "Infinity"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7950133641896353`*^9, 3.795013387221075*^9}, 
   3.7950144986427417`*^9, 3.7950612994895797`*^9, {3.7950616587562065`*^9, 
   3.795061659686753*^9}, {3.795063643311244*^9, 3.795063643474767*^9}, {
   3.7950712012790136`*^9, 3.7950712093654013`*^9}, 3.7950716754280596`*^9, {
   3.795071711720945*^9, 3.7950717224403124`*^9}, 3.795073129780592*^9, 
   3.7950884884416656`*^9, {3.795099089563261*^9, 3.795099089693878*^9}, 
   3.795109811948762*^9, {3.79511396568373*^9, 3.7951139658223195`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Verbosity", "\[Rule]", "1"}], ",", 
   RowBox[{"MaxLines", "\[Rule]", "\[Infinity]"}], ",", 
   RowBox[{"PrintStack", "\[Rule]", "None"}], ",", 
   RowBox[{"StackPattern", "\[Rule]", "None"}], ",", 
   RowBox[{
   "QuantumAlgebra`Options`Private`LinesAlreadyPrinted", "\[Rule]", "0"}], 
   ",", 
   RowBox[{"DefinitionLevel", "\[Rule]", "3"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7951139667957497`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"hamiltonian", "=", 
  RowBox[{
   RowBox[{"H", "//", "QAEvaluate2"}], "//", "QATiming"}]}]], "Input",
 CellChangeTimes->{{3.7531828032556176`*^9, 3.7531828110986414`*^9}, {
  3.7536121486020994`*^9, 3.7536121637905006`*^9}, {3.764589693203017*^9, 
  3.764589696269812*^9}, {3.764591771005744*^9, 3.7645917750997877`*^9}, {
  3.764764903944191*^9, 3.7647649041376686`*^9}, {3.769091129017764*^9, 
  3.769091130249447*^9}, {3.7949789730576506`*^9, 3.794978973298008*^9}, {
  3.794991034561247*^9, 3.7949910385017138`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"Sun 12 Apr 2020 15:27:01\"\>", ",", "176.265625`"}], "}"}], 
   ",", 
   RowBox[{
    RowBox[{"2", " ", 
     OverscriptBox["1", "^"], " ", 
     RowBox[{
      SubscriptBox["\[Integral]", "\[Infinity]"], 
      RowBox[{
       SubscriptBox["k", "0"], 
       RowBox[{
        SuperscriptBox["\[DifferentialD]", "3"], "k"}]}]}]}], "-", 
    RowBox[{
     SubscriptBox["\[Integral]", "\[Infinity]"], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubsuperscriptBox[
            OverscriptBox["a", "^"], 
            RowBox[{
             SubscriptBox["k", "1"], ",", 
             SubscriptBox["k", "2"], ",", 
             SubscriptBox["k", "3"]}], 
            RowBox[{"0", ",", "\[Dagger]"}]], "\[CenterDot]", 
           SubsuperscriptBox[
            OverscriptBox["a", "^"], 
            RowBox[{
             SubscriptBox["k", "1"], ",", 
             SubscriptBox["k", "2"], ",", 
             SubscriptBox["k", "3"]}], "0"]}], "-", 
          RowBox[{
           SubsuperscriptBox[
            OverscriptBox["a", "^"], 
            RowBox[{
             SubscriptBox["k", "1"], ",", 
             SubscriptBox["k", "2"], ",", 
             SubscriptBox["k", "3"]}], 
            RowBox[{"1", ",", "\[Dagger]"}]], "\[CenterDot]", 
           SubsuperscriptBox[
            OverscriptBox["a", "^"], 
            RowBox[{
             SubscriptBox["k", "1"], ",", 
             SubscriptBox["k", "2"], ",", 
             SubscriptBox["k", "3"]}], "1"]}], "-", 
          RowBox[{
           SubsuperscriptBox[
            OverscriptBox["a", "^"], 
            RowBox[{
             SubscriptBox["k", "1"], ",", 
             SubscriptBox["k", "2"], ",", 
             SubscriptBox["k", "3"]}], 
            RowBox[{"2", ",", "\[Dagger]"}]], "\[CenterDot]", 
           SubsuperscriptBox[
            OverscriptBox["a", "^"], 
            RowBox[{
             SubscriptBox["k", "1"], ",", 
             SubscriptBox["k", "2"], ",", 
             SubscriptBox["k", "3"]}], "2"]}], "-", 
          RowBox[{
           SubsuperscriptBox[
            OverscriptBox["a", "^"], 
            RowBox[{
             SubscriptBox["k", "1"], ",", 
             SubscriptBox["k", "2"], ",", 
             SubscriptBox["k", "3"]}], 
            RowBox[{"3", ",", "\[Dagger]"}]], "\[CenterDot]", 
           SubsuperscriptBox[
            OverscriptBox["a", "^"], 
            RowBox[{
             SubscriptBox["k", "1"], ",", 
             SubscriptBox["k", "2"], ",", 
             SubscriptBox["k", "3"]}], "3"]}]}], ")"}], " ", 
        SubscriptBox["k", "0"]}], ")"}], 
      RowBox[{
       SuperscriptBox["\[DifferentialD]", "3"], "k"}]}]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.795015122459836*^9, 3.7950175725965776`*^9, 
  3.79506212324234*^9, 3.795062698049274*^9, 3.7950640356209755`*^9, 
  3.7950655280977745`*^9, 3.7950716613257227`*^9, 3.7950719792469125`*^9, 
  3.795073027481552*^9, 3.795074212513315*^9, 3.7950750812805147`*^9, 
  3.795088070141564*^9, 3.795088667911917*^9, 3.795089117260785*^9, 
  3.795091674631892*^9, 3.7950923460419345`*^9, 3.7950992861058383`*^9, 
  3.7950996202921143`*^9, 3.7951083896310883`*^9, 3.795110400790847*^9, 
  3.7951149785720387`*^9, 3.79514832767352*^9, 3.7951497525282006`*^9, 
  3.795609070547209*^9, 3.7956106255677795`*^9, 3.7956116238791656`*^9, 
  3.795666492009205*^9, 3.795684267997534*^9, 3.7956869991298084`*^9},
 Background->RGBColor[1, 1, 0.85]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Elaboration of Simplification Chain", "Subsection",
 CellChangeTimes->{{3.7647358980787015`*^9, 3.7647359133707933`*^9}}],

Cell[CellGroupData[{

Cell["Initial Calculation", "Subsubsection",
 CellChangeTimes->{{3.7652976846027355`*^9, 3.7652976967223144`*^9}}],

Cell[BoxData[
 RowBox[{"h1", "=", 
  RowBox[{"H", "//", "Timing"}]}]], "Input",
 CellChangeTimes->{
  3.7647359335787315`*^9, {3.764736007328117*^9, 3.7647360087423334`*^9}, {
   3.764737360322072*^9, 3.764737364390156*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Join", "Subsubsection",
 CellChangeTimes->{{3.765297729704084*^9, 3.765297731650878*^9}, {
  3.794991153993739*^9, 3.794991158468776*^9}}],

Cell[BoxData[
 RowBox[{"h2", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"h1", "[", 
     RowBox[{"[", "2", "]"}], "]"}], "//", 
    RowBox[{"QAReplace", "[", "\"\<IntegrateJoin\>\"", "]"}]}], "//", 
   "Timing"}]}]], "Input",
 CellChangeTimes->{{3.7647360758782096`*^9, 3.7647360805446987`*^9}, {
   3.764737391432677*^9, 3.764737401466857*^9}, 3.7650398401209702`*^9, 
   3.7650987128425226`*^9, 3.7946718942521906`*^9, {3.794755078794705*^9, 
   3.7947550813628078`*^9}, 3.794755476158491*^9, {3.794764132394354*^9, 
   3.7947641464597564`*^9}, {3.7947645464966497`*^9, 3.794764560641837*^9}, {
   3.794764598159548*^9, 3.794764668517471*^9}, 3.794764704141245*^9, {
   3.7947656248479223`*^9, 3.7947656344113626`*^9}, 3.7949789010737*^9}],

Cell["\<\
Goal: Join integrals
Result: The integration order is exchanged\
\>", "Text",
 CellChangeTimes->{{3.7647368027337227`*^9, 3.7647368890658064`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Apply Commutators", "Subsubsection",
 CellChangeTimes->{{3.7652978117321944`*^9, 3.765297820617427*^9}, {
   3.7942312575232244`*^9, 3.7942312818023825`*^9}, 3.794237739391265*^9, {
   3.7949911649235225`*^9, 3.7949911703849235`*^9}}],

Cell[BoxData[
 RowBox[{"h3", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"h2", "[", 
     RowBox[{"[", "2", "]"}], "]"}], "//", 
    RowBox[{"QAReplace", "[", "\"\<CommutatorLocal-Vectors\>\"", "]"}]}], "//",
    "Timing"}]}]], "Input",
 CellChangeTimes->{{3.7647361735290737`*^9, 3.764736201021571*^9}, {
   3.7647374169932966`*^9, 3.764737422609273*^9}, 3.765098763074263*^9, 
   3.7689063486574993`*^9, 3.7692529300477843`*^9, {3.794231053177472*^9, 
   3.794231080513405*^9}, 3.7942314720568266`*^9, {3.7944583043637085`*^9, 
   3.794458306026265*^9}, 3.7946646533511877`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Split, DistributionLaw", "Subsubsection",
 CellChangeTimes->{{3.765297905039586*^9, 3.7652979070651703`*^9}, {
  3.7942378180954523`*^9, 3.7942378199115973`*^9}, {3.7949911779207783`*^9, 
  3.7949911963448915`*^9}}],

Cell[BoxData[
 RowBox[{"h5", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"h3", "[", 
     RowBox[{"[", "2", "]"}], "]"}], "//", 
    RowBox[{"QAReplaceRepeated", "[", "\"\<IntegrateSplit\>\"", "]"}]}], "//",
    "Timing"}]}]], "Input",
 CellChangeTimes->{{3.7651074494007945`*^9, 3.765107476193163*^9}, 
   3.7652978887641263`*^9, {3.769252988364731*^9, 3.7692530090693398`*^9}, {
   3.7692627018137026`*^9, 3.7692627288403983`*^9}, {3.7692632483056307`*^9, 
   3.769263250295337*^9}, {3.794237948634473*^9, 3.7942379855812163`*^9}, 
   3.7942847356634827`*^9, {3.794632765438269*^9, 3.7946327701077766`*^9}, {
   3.7946508054633293`*^9, 3.794650835703492*^9}, 3.794672127288561*^9, {
   3.7946723957958126`*^9, 3.7946723977039833`*^9}, 3.794815661273202*^9, 
   3.7949789292252154`*^9}],

Cell[BoxData[
 RowBox[{"h6", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"h5", "[", 
     RowBox[{"[", "2", "]"}], "]"}], "//", 
    RowBox[{"QAReplaceRepeated", "[", "\"\<FullDistributionLaw\>\"", "]"}]}], 
   "//", "Timing"}]}]], "Input",
 CellChangeTimes->{{3.7946508440282393`*^9, 3.7946508529982615`*^9}, {
  3.7947241747904015`*^9, 3.7947241929718375`*^9}}],

Cell["\<\
Volume integrals are resolved, double integrals are resolved.\
\>", "Text",
 CellChangeTimes->{{3.7652979995537863`*^9, 3.7652980304780235`*^9}}],

Cell["\<\
Goal: Simplify single integrals
Result: Application of distribution law lets extract constant factors and \
permits further simplification like resolution of volume integrals and double \
integrals. Only one not nested integral from 3 nested ones remains.\
\>", "Text",
 CellChangeTimes->{{3.764737060760664*^9, 3.764737168584217*^9}, {
   3.764737281179407*^9, 3.764737316970703*^9}, {3.764737523979766*^9, 
   3.764737526868039*^9}, {3.7647375917604475`*^9, 3.7647376371530504`*^9}, 
   3.7654294175429697`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Join, DistributionLaw", "Subsubsection",
 CellChangeTimes->{{3.765298552242305*^9, 3.765298571746129*^9}, {
  3.794238740105754*^9, 3.7942387430578637`*^9}, {3.794238825220231*^9, 
  3.7942388288026857`*^9}, {3.7949912043365035`*^9, 3.7949912202968397`*^9}}],

Cell[BoxData[
 RowBox[{"h7", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"h6", "[", 
     RowBox[{"[", "2", "]"}], "]"}], "//", 
    RowBox[{"QAReplace", "[", "\"\<IntegrateJoin\>\"", "]"}]}], "//", 
   "Timing"}]}]], "Input",
 CellChangeTimes->{{3.764736671142496*^9, 3.764736675508848*^9}, {
   3.7647374639189315`*^9, 3.764737469771239*^9}, 3.765082561002779*^9, {
   3.765095165797535*^9, 3.765095167790205*^9}, {3.7650989471528187`*^9, 
   3.765098978578753*^9}, {3.7652767267507124`*^9, 3.7652767333011904`*^9}, {
   3.7652981375665503`*^9, 3.7652981426130495`*^9}, {3.768907053270625*^9, 
   3.7689070930780907`*^9}, {3.769263629838964*^9, 3.769263639440281*^9}, {
   3.7692637918236156`*^9, 3.76926380165631*^9}, 3.769264306944508*^9, 
   3.7693338620588984`*^9, 3.794210121973859*^9, 3.7942388113493094`*^9, {
   3.794284777591403*^9, 3.794284805798479*^9}, 3.7942866850423355`*^9, {
   3.7942869711126337`*^9, 3.7942869754689827`*^9}, {3.7945651703142495`*^9, 
   3.7945651723089237`*^9}, 3.7946362666513667`*^9, {3.7946509258535547`*^9, 
   3.794650935188602*^9}, 3.794672175881668*^9, {3.7946732824348173`*^9, 
   3.7946732845890923`*^9}, 3.7947182714931355`*^9, {3.7947183790711465`*^9, 
   3.7947183810638175`*^9}, 3.7947240233836403`*^9, {3.794736667345191*^9, 
   3.794736669313893*^9}, 3.794753957075539*^9, {3.7947559950913134`*^9, 
   3.7947560006394453`*^9}, 3.7947659524454365`*^9, 3.7949789037286024`*^9}],

Cell[BoxData[
 RowBox[{"h8", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"h7", "[", 
     RowBox[{"[", "2", "]"}], "]"}], "//", 
    RowBox[{"QAReplaceRepeated", "[", "\"\<FullDistributionLaw\>\"", "]"}]}], 
   "//", "Timing"}]}]], "Input",
 CellChangeTimes->{{3.7946508440282393`*^9, 3.7946508529982615`*^9}, 
   3.79465091089554*^9, {3.7946509519258595`*^9, 3.794650963309429*^9}}],

Cell["\<\
Goal: Apply contraction
Result: Outstanding simplifications\
\>", "Text",
 CellChangeTimes->{{3.7647379264876556`*^9, 3.7647380497628403`*^9}, {
  3.794239293686801*^9, 3.794239297636243*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Simplification", "Subsubsection",
 CellChangeTimes->{{3.765298712780841*^9, 3.765298717652809*^9}, {
   3.7652988497055545`*^9, 3.7652988522697363`*^9}, 3.794239592052211*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"h9", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"h8", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "//", 
        RowBox[{"QAReplace", "[", "\"\<Vectors\>\"", "]"}]}], "//", 
       RowBox[{"QASimplify", "[", "]"}]}], "//", 
      RowBox[{"QAReplace", "[", "\"\<Vectors\>\"", "]"}]}], "//", 
     RowBox[{"QASimplify", "[", "]"}]}], "//", "Timing"}]}], " ", 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.7647381991506815`*^9, 3.764738253730645*^9}, {
   3.7647387640014753`*^9, 3.764738765896406*^9}, 3.764763724524659*^9, 
   3.7647639171623273`*^9, {3.764764046237031*^9, 3.7647640645460525`*^9}, {
   3.764764395196371*^9, 3.7647644001222*^9}, {3.7649404906048965`*^9, 
   3.764940492538717*^9}, {3.7649986582734137`*^9, 3.7649986710861764`*^9}, 
   3.765000087429845*^9, {3.765000289409845*^9, 3.765000298759842*^9}, {
   3.7650196851329765`*^9, 3.765019694748255*^9}, 3.765019865254609*^9, 
   3.7650203603146987`*^9, 3.7650318987569637`*^9, {3.7652769360124807`*^9, 
   3.7652769361281347`*^9}, {3.765276971057694*^9, 3.765276973599891*^9}, 
   3.7652773580808516`*^9, {3.76529861080165*^9, 3.765298618598792*^9}, 
   3.7689071898851066`*^9, 3.7692534819215107`*^9, 3.7692542648533134`*^9, 
   3.769257339671487*^9, {3.769257417714718*^9, 3.76925743789872*^9}, 
   3.769258089592368*^9, {3.7693339146958985`*^9, 3.769333914822853*^9}, 
   3.769334066895273*^9, 3.769335943658669*^9, {3.7942304044287043`*^9, 
   3.7942304109552727`*^9}, {3.794239555438574*^9, 3.79423956957031*^9}, {
   3.7942440781003137`*^9, 3.794244084645788*^9}, {3.794246532861232*^9, 
   3.79424653378975*^9}, {3.7942871356009436`*^9, 3.7942871387634697`*^9}, {
   3.794287975368723*^9, 3.7942879958843937`*^9}, {3.7946509878688984`*^9, 
   3.7946509909486656`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"90.703125`", ",", 
   RowBox[{
    RowBox[{"2", " ", 
     OverscriptBox["1", "^"], " ", 
     RowBox[{
      SubscriptBox["\[Integral]", "\[Infinity]"], 
      RowBox[{
       SubscriptBox["k", "0"], 
       RowBox[{
        SuperscriptBox["\[DifferentialD]", "3"], "k"}]}]}]}], "-", 
    RowBox[{
     SubscriptBox["\[Integral]", "\[Infinity]"], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubsuperscriptBox[
            OverscriptBox["a", "^"], 
            RowBox[{
             SubscriptBox["k", "1"], ",", 
             SubscriptBox["k", "2"], ",", 
             SubscriptBox["k", "3"]}], 
            RowBox[{"0", ",", "\[Dagger]"}]], "\[CenterDot]", 
           SubsuperscriptBox[
            OverscriptBox["a", "^"], 
            RowBox[{
             SubscriptBox["k", "1"], ",", 
             SubscriptBox["k", "2"], ",", 
             SubscriptBox["k", "3"]}], "0"]}], "-", 
          RowBox[{
           SubsuperscriptBox[
            OverscriptBox["a", "^"], 
            RowBox[{
             SubscriptBox["k", "1"], ",", 
             SubscriptBox["k", "2"], ",", 
             SubscriptBox["k", "3"]}], 
            RowBox[{"1", ",", "\[Dagger]"}]], "\[CenterDot]", 
           SubsuperscriptBox[
            OverscriptBox["a", "^"], 
            RowBox[{
             SubscriptBox["k", "1"], ",", 
             SubscriptBox["k", "2"], ",", 
             SubscriptBox["k", "3"]}], "1"]}], "-", 
          RowBox[{
           SubsuperscriptBox[
            OverscriptBox["a", "^"], 
            RowBox[{
             SubscriptBox["k", "1"], ",", 
             SubscriptBox["k", "2"], ",", 
             SubscriptBox["k", "3"]}], 
            RowBox[{"2", ",", "\[Dagger]"}]], "\[CenterDot]", 
           SubsuperscriptBox[
            OverscriptBox["a", "^"], 
            RowBox[{
             SubscriptBox["k", "1"], ",", 
             SubscriptBox["k", "2"], ",", 
             SubscriptBox["k", "3"]}], "2"]}], "-", 
          RowBox[{
           SubsuperscriptBox[
            OverscriptBox["a", "^"], 
            RowBox[{
             SubscriptBox["k", "1"], ",", 
             SubscriptBox["k", "2"], ",", 
             SubscriptBox["k", "3"]}], 
            RowBox[{"3", ",", "\[Dagger]"}]], "\[CenterDot]", 
           SubsuperscriptBox[
            OverscriptBox["a", "^"], 
            RowBox[{
             SubscriptBox["k", "1"], ",", 
             SubscriptBox["k", "2"], ",", 
             SubscriptBox["k", "3"]}], "3"]}]}], ")"}], " ", 
        SubscriptBox["k", "0"]}], ")"}], 
      RowBox[{
       SuperscriptBox["\[DifferentialD]", "3"], "k"}]}]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->CompressedData["
1:eJwVxU0og3EcAOAptTX7CFutHNaWGiNkZMjHm2FDatSUZZhJQ20OStqMlZLV
Xopy8JXVHJCNhVDU5mBiN5GVltD4JyFfOfj9Dk+PxGhp6k5gMBgK8Pt6qljj
EMp7ljaAB7RF9C5saBlaxTNjDWd4zuD6Bz4j+fJzuYRiiwQPuNHjucmAo3OK
DDlstkdqcK7LdIcHt1O/8SQ/zcuCyS2XLoBZI1YP/rcxFsMTSSh9Cy7lVxTj
6vnoxSGs2yw8XhQQqjFilS/B6j3Hda2QUKbz+2I13CruE2vg3oOFAH6p1YVx
o2k6tQ6eeMxTWmDl5o/UCpd7S0IxFaHCplxDHGbkW21PsMw8RT/D+/qeFbxZ
4ZO8wh33rso3OCQrm3qH7W7bMs55iauY1YTaY6ud+CTfuY2PvmlIMjwc+EzW
wyqZI9gGC331cTfcJeusouHZK17/DswcGGeF4BShqP0EPpJmDzJrCPUPyWq9
qA==
  "]]
}, Open  ]],

Cell["\<\
Goal: Apply substitution to eliminate polarization vectors
Result: Done.\
\>", "Text",
 CellChangeTimes->{{3.7647390539951086`*^9, 3.7647391239669037`*^9}, {
  3.7647643604557266`*^9, 3.7647643632542615`*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3-Momentum", "Subsection",
 CellChangeTimes->{{3.764136688256733*^9, 3.764136691932936*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[GothicP]", "[", "i_", "]"}], ":=", 
  RowBox[{"-", 
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{
      SubscriptBox["g", 
       RowBox[{"\[Mu]", ",", "\[Nu]"}]], " ", 
      RowBox[{
       RowBox[{"deriv0", "[", 
        RowBox[{"\[Mu]", ",", "0"}], "]"}], "\[CenterDot]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"deriv0", "[", 
          RowBox[{"\[Nu]", ",", "i"}], "]"}], "/.", 
         RowBox[{"k", "\[Rule]", "k1"}]}], ")"}]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Mu]", ",", "0", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Nu]", ",", "0", ",", "3"}], "}"}]}], 
    "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p", "[", "i_", "]"}], ":=", 
  RowBox[{
   SubscriptBox["\[Integral]", "\[Infinity]"], 
   RowBox[{
    RowBox[{"\[GothicP]", "[", "i", "]"}], 
    RowBox[{
     SuperscriptBox["\[DifferentialD]", "3"], "x"}]}]}]}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.7641367019750657`*^9, 3.764136837580315*^9}, {
  3.7641368828461857`*^9, 3.7641369261138277`*^9}, {3.7641369637870483`*^9, 
  3.7641370048731747`*^9}, {3.7642163294658937`*^9, 3.764216359648203*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"momentum", "=", 
  RowBox[{
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"QAEvaluate2", "[", 
       RowBox[{"p", "[", "#1", "]"}], "]"}], "&"}], ",", 
     RowBox[{"Range", "[", "3", "]"}]}], "]"}], "//", "QATiming"}]}]], "Input",
 CellChangeTimes->{{3.764216524336418*^9, 3.764216555885026*^9}, {
   3.7642168754860587`*^9, 3.7642168906438785`*^9}, {3.7642169465114636`*^9, 
   3.764216960933875*^9}, 3.7644035404250803`*^9, {3.764497916721094*^9, 
   3.764497917309475*^9}, 3.7645089264163823`*^9, 3.764845335944611*^9, 
   3.7648457560678873`*^9, {3.7949794982703686`*^9, 3.794979498627383*^9}, {
   3.7949913129916515`*^9, 3.7949913150252137`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"Sun 12 Apr 2020 15:31:21\"\>", ",", "64.921875`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Integral]", "\[Infinity]"], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{
              SubsuperscriptBox[
               OverscriptBox["a", "^"], 
               RowBox[{
                SubscriptBox["k", "1"], ",", 
                SubscriptBox["k", "2"], ",", 
                SubscriptBox["k", "3"]}], 
               RowBox[{"0", ",", "\[Dagger]"}]], "\[CenterDot]", 
              SubsuperscriptBox[
               OverscriptBox["a", "^"], 
               RowBox[{
                SubscriptBox["k", "1"], ",", 
                SubscriptBox["k", "2"], ",", 
                SubscriptBox["k", "3"]}], "0"]}], ")"}]}], "+", 
           RowBox[{
            SubsuperscriptBox[
             OverscriptBox["a", "^"], 
             RowBox[{
              SubscriptBox["k", "1"], ",", 
              SubscriptBox["k", "2"], ",", 
              SubscriptBox["k", "3"]}], 
             RowBox[{"1", ",", "\[Dagger]"}]], "\[CenterDot]", 
            SubsuperscriptBox[
             OverscriptBox["a", "^"], 
             RowBox[{
              SubscriptBox["k", "1"], ",", 
              SubscriptBox["k", "2"], ",", 
              SubscriptBox["k", "3"]}], "1"]}], "+", 
           RowBox[{
            SubsuperscriptBox[
             OverscriptBox["a", "^"], 
             RowBox[{
              SubscriptBox["k", "1"], ",", 
              SubscriptBox["k", "2"], ",", 
              SubscriptBox["k", "3"]}], 
             RowBox[{"2", ",", "\[Dagger]"}]], "\[CenterDot]", 
            SubsuperscriptBox[
             OverscriptBox["a", "^"], 
             RowBox[{
              SubscriptBox["k", "1"], ",", 
              SubscriptBox["k", "2"], ",", 
              SubscriptBox["k", "3"]}], "2"]}], "+", 
           RowBox[{
            SubsuperscriptBox[
             OverscriptBox["a", "^"], 
             RowBox[{
              SubscriptBox["k", "1"], ",", 
              SubscriptBox["k", "2"], ",", 
              SubscriptBox["k", "3"]}], 
             RowBox[{"3", ",", "\[Dagger]"}]], "\[CenterDot]", 
            SubsuperscriptBox[
             OverscriptBox["a", "^"], 
             RowBox[{
              SubscriptBox["k", "1"], ",", 
              SubscriptBox["k", "2"], ",", 
              SubscriptBox["k", "3"]}], "3"]}]}], ")"}], " ", 
         SubscriptBox["k", "1"]}], ")"}], 
       RowBox[{
        SuperscriptBox["\[DifferentialD]", "3"], "k"}]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Integral]", "\[Infinity]"], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{
              SubsuperscriptBox[
               OverscriptBox["a", "^"], 
               RowBox[{
                SubscriptBox["k", "1"], ",", 
                SubscriptBox["k", "2"], ",", 
                SubscriptBox["k", "3"]}], 
               RowBox[{"0", ",", "\[Dagger]"}]], "\[CenterDot]", 
              SubsuperscriptBox[
               OverscriptBox["a", "^"], 
               RowBox[{
                SubscriptBox["k", "1"], ",", 
                SubscriptBox["k", "2"], ",", 
                SubscriptBox["k", "3"]}], "0"]}], ")"}]}], "+", 
           RowBox[{
            SubsuperscriptBox[
             OverscriptBox["a", "^"], 
             RowBox[{
              SubscriptBox["k", "1"], ",", 
              SubscriptBox["k", "2"], ",", 
              SubscriptBox["k", "3"]}], 
             RowBox[{"1", ",", "\[Dagger]"}]], "\[CenterDot]", 
            SubsuperscriptBox[
             OverscriptBox["a", "^"], 
             RowBox[{
              SubscriptBox["k", "1"], ",", 
              SubscriptBox["k", "2"], ",", 
              SubscriptBox["k", "3"]}], "1"]}], "+", 
           RowBox[{
            SubsuperscriptBox[
             OverscriptBox["a", "^"], 
             RowBox[{
              SubscriptBox["k", "1"], ",", 
              SubscriptBox["k", "2"], ",", 
              SubscriptBox["k", "3"]}], 
             RowBox[{"2", ",", "\[Dagger]"}]], "\[CenterDot]", 
            SubsuperscriptBox[
             OverscriptBox["a", "^"], 
             RowBox[{
              SubscriptBox["k", "1"], ",", 
              SubscriptBox["k", "2"], ",", 
              SubscriptBox["k", "3"]}], "2"]}], "+", 
           RowBox[{
            SubsuperscriptBox[
             OverscriptBox["a", "^"], 
             RowBox[{
              SubscriptBox["k", "1"], ",", 
              SubscriptBox["k", "2"], ",", 
              SubscriptBox["k", "3"]}], 
             RowBox[{"3", ",", "\[Dagger]"}]], "\[CenterDot]", 
            SubsuperscriptBox[
             OverscriptBox["a", "^"], 
             RowBox[{
              SubscriptBox["k", "1"], ",", 
              SubscriptBox["k", "2"], ",", 
              SubscriptBox["k", "3"]}], "3"]}]}], ")"}], " ", 
         SubscriptBox["k", "2"]}], ")"}], 
       RowBox[{
        SuperscriptBox["\[DifferentialD]", "3"], "k"}]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Integral]", "\[Infinity]"], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{
              SubsuperscriptBox[
               OverscriptBox["a", "^"], 
               RowBox[{
                SubscriptBox["k", "1"], ",", 
                SubscriptBox["k", "2"], ",", 
                SubscriptBox["k", "3"]}], 
               RowBox[{"0", ",", "\[Dagger]"}]], "\[CenterDot]", 
              SubsuperscriptBox[
               OverscriptBox["a", "^"], 
               RowBox[{
                SubscriptBox["k", "1"], ",", 
                SubscriptBox["k", "2"], ",", 
                SubscriptBox["k", "3"]}], "0"]}], ")"}]}], "+", 
           RowBox[{
            SubsuperscriptBox[
             OverscriptBox["a", "^"], 
             RowBox[{
              SubscriptBox["k", "1"], ",", 
              SubscriptBox["k", "2"], ",", 
              SubscriptBox["k", "3"]}], 
             RowBox[{"1", ",", "\[Dagger]"}]], "\[CenterDot]", 
            SubsuperscriptBox[
             OverscriptBox["a", "^"], 
             RowBox[{
              SubscriptBox["k", "1"], ",", 
              SubscriptBox["k", "2"], ",", 
              SubscriptBox["k", "3"]}], "1"]}], "+", 
           RowBox[{
            SubsuperscriptBox[
             OverscriptBox["a", "^"], 
             RowBox[{
              SubscriptBox["k", "1"], ",", 
              SubscriptBox["k", "2"], ",", 
              SubscriptBox["k", "3"]}], 
             RowBox[{"2", ",", "\[Dagger]"}]], "\[CenterDot]", 
            SubsuperscriptBox[
             OverscriptBox["a", "^"], 
             RowBox[{
              SubscriptBox["k", "1"], ",", 
              SubscriptBox["k", "2"], ",", 
              SubscriptBox["k", "3"]}], "2"]}], "+", 
           RowBox[{
            SubsuperscriptBox[
             OverscriptBox["a", "^"], 
             RowBox[{
              SubscriptBox["k", "1"], ",", 
              SubscriptBox["k", "2"], ",", 
              SubscriptBox["k", "3"]}], 
             RowBox[{"3", ",", "\[Dagger]"}]], "\[CenterDot]", 
            SubsuperscriptBox[
             OverscriptBox["a", "^"], 
             RowBox[{
              SubscriptBox["k", "1"], ",", 
              SubscriptBox["k", "2"], ",", 
              SubscriptBox["k", "3"]}], "3"]}]}], ")"}], " ", 
         SubscriptBox["k", "3"]}], ")"}], 
       RowBox[{
        SuperscriptBox["\[DifferentialD]", "3"], "k"}]}]}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQBeJjz7fHruF+4zjjYEYSmF4T0gmiO2fGfwLRJyIsVrPz
vHFsvut3E0S7T3TR4APSs9N60kG0neWrOwJAetrMjWy6QHq1smGZKZBuCU2+
A6IDTi4QNQfSfhP2s1gA6VvVoczWQPqKHkstiC7Im2VhC6TfbVHgsAPS7JP6
9ZKAdBjXpr4dQHrBEs2c+0BaS15jPYh+2qcXspf3jePmDfcjwvjeOGqUhvTO
F3njeCPgStFeEG3dufs7kLaZVmD+A0jH+DfFgehPAv7ywqJvHI87h2zgdHvj
yH/CNCESSG/PklaNB9J7I8vTQbQrH0dPBpAO2eO9AkTf5HmxC0S3Ld7xDkxz
Nv5sANJfI3kCGoH0k7KKNBDds2gG/xQgnX6Qo3UNkC6Y8fXGCvc3jueyE+9u
AtIAp1Wmew==
  "],
 Background->RGBColor[1, 1, 0.85]]
}, Open  ]],

Cell["\<\
The 3-Momentum is different from the Hamiltonian in that it requires \
additional simplification. This is due to the fact that there are some \
additional terms with anti-symmetric integrands. These terms disappear after \
simplification because their integral results in null.\
\>", "Text",
 CellChangeTimes->{{3.7648460487195597`*^9, 3.7648461571225686`*^9}, {
   3.764846194794821*^9, 3.7648462703227754`*^9}, {3.7654292895237713`*^9, 
   3.7654292913559003`*^9}, 3.7654294329090695`*^9}]
}, Open  ]],

Cell["Tests", "Subsection",
 CellChangeTimes->{{3.7643396380727463`*^9, 3.7643396388367414`*^9}}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{838, 879},
WindowMargins->{{418, Automatic}, {Automatic, 96}},
PrintingPageRange->{Automatic, Automatic},
CellContext->"Global`",
InputAliases->{"com" -> SubscriptBox[
    RowBox[{"[", "\[SelectionPlaceholder]", "]"}], "-"], "op" -> 
  OverscriptBox["\[SelectionPlaceholder]", "^"], "hop" -> SuperscriptBox[
    OverscriptBox["\[SelectionPlaceholder]", "^"], "\[Dagger]"], "opd" -> 
  SubscriptBox[
    OverscriptBox["\[SelectionPlaceholder]", "^"], "\[SelectionPlaceholder]"],
   "opu" -> SuperscriptBox[
    OverscriptBox["\[SelectionPlaceholder]", "^"], "\[SelectionPlaceholder]"],
   "opdu" -> SubsuperscriptBox[
    OverscriptBox["\[SelectionPlaceholder]", "^"], "\[SelectionPlaceholder]", 
    "\[SelectionPlaceholder]"], "hopd" -> SubsuperscriptBox[
    OverscriptBox["\[SelectionPlaceholder]", "^"], "\[SelectionPlaceholder]", 
    "\[Dagger]"], "hopu" -> SuperscriptBox[
    OverscriptBox["\[SelectionPlaceholder]", "^"], 
    RowBox[{"\[SelectionPlaceholder]", ",", "\[Dagger]"}]], "hopdu" -> 
  SubsuperscriptBox[
    OverscriptBox["\[SelectionPlaceholder]", "^"], "\[SelectionPlaceholder]", 
    RowBox[{"\[SelectionPlaceholder]", ",", "\[Dagger]"}]], "ket" -> TagBox[
    RowBox[{
      AdjustmentBox[
      "\[VerticalSeparator]", BoxMargins -> {{-0.4, 0}, {0, 0}}], 
      AdjustmentBox[
       TagBox[
       "\[SelectionPlaceholder]", QuantumAlgebra`QuantumNotation`KetArgs, 
        BaseStyle -> "BraKetArg"], BoxBaselineShift -> 0], 
      "\[RightAngleBracket]"}], QuantumAlgebra`Ket, BaseStyle -> 
    "KetWrapper"], "bra" -> TagBox[
    RowBox[{"\[LeftAngleBracket]", 
      AdjustmentBox[
       TagBox[
       "\[SelectionPlaceholder]", QuantumAlgebra`QuantumNotation`BraArgs, 
        BaseStyle -> "BraKetArg"], BoxBaselineShift -> 0], 
      AdjustmentBox[
      "\[VerticalSeparator]", BoxMargins -> {{0, -0.2}, {0, 0}}]}], 
    QuantumAlgebra`Bra, BaseStyle -> "BraWrapper"], "braket" -> TagBox[
    RowBox[{"\[LeftAngleBracket]", 
      AdjustmentBox[
       RowBox[{
         TagBox[
         "\[SelectionPlaceholder]", QuantumAlgebra`QuantumNotation`BraKetArgs,
           BaseStyle -> "BraKetArg"], "\[VerticalSeparator]", 
         TagBox[
         "\[SelectionPlaceholder]", QuantumAlgebra`QuantumNotation`BraKetArgs,
           BaseStyle -> "BraKetArg"]}], BoxBaselineShift -> 0], 
      "\[RightAngleBracket]"}], QuantumAlgebra`BraKet, BaseStyle -> 
    "BraKetWrapper"], "ketd" -> TagBox[
    SubscriptBox[
     RowBox[{
       AdjustmentBox[
       "\[VerticalSeparator]", BoxMargins -> {{-0.4, 0}, {0, 0}}], 
       AdjustmentBox[
        TagBox[
        "\[SelectionPlaceholder]", QuantumAlgebra`QuantumNotation`KetArgs, 
         BaseStyle -> "BraKetArg"], BoxBaselineShift -> 0], 
       "\[RightAngleBracket]"}], 
     TagBox[
      AdjustmentBox[
       TagBox[
       "\[SelectionPlaceholder]", QuantumAlgebra`QuantumNotation`KetArgs, 
        BaseStyle -> "BraKetArg"], BoxBaselineShift -> 0], 
      QuantumAlgebra`QuantumNotation`UDScript, BaseStyle -> "RIndex"]], 
    QuantumAlgebra`Ket, BaseStyle -> "KetWrapper"], "ketu" -> TagBox[
    SuperscriptBox[
     RowBox[{
       AdjustmentBox[
       "\[VerticalSeparator]", BoxMargins -> {{-0.4, 0}, {0, 0}}], 
       AdjustmentBox[
        TagBox[
        "\[SelectionPlaceholder]", QuantumAlgebra`QuantumNotation`KetArgs, 
         BaseStyle -> "BraKetArg"], BoxBaselineShift -> 0], 
       "\[RightAngleBracket]"}], 
     TagBox[
      AdjustmentBox[
       TagBox[
       "\[SelectionPlaceholder]", QuantumAlgebra`QuantumNotation`KetArgs, 
        BaseStyle -> "BraKetArg"], BoxBaselineShift -> 0], 
      QuantumAlgebra`QuantumNotation`UDScript, BaseStyle -> "RIndex"]], 
    QuantumAlgebra`Ket, BaseStyle -> "KetWrapper"], "ketdu" -> TagBox[
    SubsuperscriptBox[
     RowBox[{
       AdjustmentBox[
       "\[VerticalSeparator]", BoxMargins -> {{-0.4, 0}, {0, 0}}], 
       AdjustmentBox[
        TagBox[
        "\[SelectionPlaceholder]", QuantumAlgebra`QuantumNotation`KetArgs, 
         BaseStyle -> "BraKetArg"], BoxBaselineShift -> 0], 
       "\[RightAngleBracket]"}], 
     TagBox[
      AdjustmentBox[
       TagBox[
       "\[SelectionPlaceholder]", QuantumAlgebra`QuantumNotation`KetArgs, 
        BaseStyle -> "BraKetArg"], BoxBaselineShift -> 0], 
      QuantumAlgebra`QuantumNotation`UDScript, BaseStyle -> "RIndex"], 
     TagBox[
      AdjustmentBox[
       TagBox[
       "\[SelectionPlaceholder]", QuantumAlgebra`QuantumNotation`KetArgs, 
        BaseStyle -> "BraKetArg"], BoxBaselineShift -> 0], 
      QuantumAlgebra`QuantumNotation`UDScript, BaseStyle -> "RIndex"]], 
    QuantumAlgebra`Ket, BaseStyle -> "KetWrapper"], "dbra" -> TagBox[
    RowBox[{
      SubscriptBox["\[InvisiblePrefixScriptBase]", 
       TagBox[
        AdjustmentBox[
         TagBox[
         "\[SelectionPlaceholder]", QuantumAlgebra`QuantumNotation`BraArgs, 
          BaseStyle -> "BraKetArg"], BoxBaselineShift -> 0], 
        QuantumAlgebra`QuantumNotation`UDScript, BaseStyle -> "LIndex"]], 
      RowBox[{"\[LeftAngleBracket]", 
        AdjustmentBox[
         TagBox[
         "\[SelectionPlaceholder]", QuantumAlgebra`QuantumNotation`BraArgs, 
          BaseStyle -> "BraKetArg"], BoxBaselineShift -> 0], 
        AdjustmentBox[
        "\[VerticalSeparator]", BoxMargins -> {{0, -0.2}, {0, 0}}]}]}], 
    QuantumAlgebra`Bra, BaseStyle -> "BraWrapper"], "ubra" -> TagBox[
    RowBox[{
      SuperscriptBox["\[InvisiblePrefixScriptBase]", 
       TagBox[
        AdjustmentBox[
         TagBox[
         "\[SelectionPlaceholder]", QuantumAlgebra`QuantumNotation`BraArgs, 
          BaseStyle -> "BraKetArg"], BoxBaselineShift -> 0], 
        QuantumAlgebra`QuantumNotation`UDScript, BaseStyle -> "LIndex"]], 
      RowBox[{"\[LeftAngleBracket]", 
        AdjustmentBox[
         TagBox[
         "\[SelectionPlaceholder]", QuantumAlgebra`QuantumNotation`BraArgs, 
          BaseStyle -> "BraKetArg"], BoxBaselineShift -> 0], 
        AdjustmentBox[
        "\[VerticalSeparator]", BoxMargins -> {{0, -0.2}, {0, 0}}]}]}], 
    QuantumAlgebra`Bra, BaseStyle -> "BraWrapper"], "dubra" -> TagBox[
    RowBox[{
      SubsuperscriptBox["\[InvisiblePrefixScriptBase]", 
       TagBox[
        AdjustmentBox[
         TagBox[
         "\[SelectionPlaceholder]", QuantumAlgebra`QuantumNotation`BraArgs, 
          BaseStyle -> "BraKetArg"], BoxBaselineShift -> 0], 
        QuantumAlgebra`QuantumNotation`UDScript, BaseStyle -> "LIndex"], 
       TagBox[
        AdjustmentBox[
         TagBox[
         "\[SelectionPlaceholder]", QuantumAlgebra`QuantumNotation`BraArgs, 
          BaseStyle -> "BraKetArg"], BoxBaselineShift -> 0], 
        QuantumAlgebra`QuantumNotation`UDScript, BaseStyle -> "LIndex"]], 
      RowBox[{"\[LeftAngleBracket]", 
        AdjustmentBox[
         TagBox[
         "\[SelectionPlaceholder]", QuantumAlgebra`QuantumNotation`BraArgs, 
          BaseStyle -> "BraKetArg"], BoxBaselineShift -> 0], 
        AdjustmentBox[
        "\[VerticalSeparator]", BoxMargins -> {{0, -0.2}, {0, 0}}]}]}], 
    QuantumAlgebra`Bra, BaseStyle -> "BraWrapper"], "braketu" -> TagBox[
    SuperscriptBox[
     RowBox[{"\[LeftAngleBracket]", 
       AdjustmentBox[
        RowBox[{
          TagBox[
          "\[SelectionPlaceholder]", 
           QuantumAlgebra`QuantumNotation`BraKetArgs, BaseStyle -> 
           "BraKetArg"], "\[VerticalSeparator]", 
          TagBox[
          "\[SelectionPlaceholder]", 
           QuantumAlgebra`QuantumNotation`BraKetArgs, BaseStyle -> 
           "BraKetArg"]}], BoxBaselineShift -> 0], "\[RightAngleBracket]"}], 
     TagBox[
      AdjustmentBox[
       TagBox[
       "\[SelectionPlaceholder]", QuantumAlgebra`QuantumNotation`KetArgs, 
        BaseStyle -> "BraKetArg"], BoxBaselineShift -> 0], 
      QuantumAlgebra`QuantumNotation`UDScript, BaseStyle -> "RIndex"]], 
    QuantumAlgebra`BraKet, BaseStyle -> "BraKetWrapper"], "braketdu" -> TagBox[
    SubsuperscriptBox[
     RowBox[{"\[LeftAngleBracket]", 
       AdjustmentBox[
        RowBox[{
          TagBox[
          "\[SelectionPlaceholder]", 
           QuantumAlgebra`QuantumNotation`BraKetArgs, BaseStyle -> 
           "BraKetArg"], "\[VerticalSeparator]", 
          TagBox[
          "\[SelectionPlaceholder]", 
           QuantumAlgebra`QuantumNotation`BraKetArgs, BaseStyle -> 
           "BraKetArg"]}], BoxBaselineShift -> 0], "\[RightAngleBracket]"}], 
     TagBox[
      AdjustmentBox[
       TagBox[
       "\[SelectionPlaceholder]", QuantumAlgebra`QuantumNotation`KetArgs, 
        BaseStyle -> "BraKetArg"], BoxBaselineShift -> 0], 
      QuantumAlgebra`QuantumNotation`UDScript, BaseStyle -> "RIndex"], 
     TagBox[
      AdjustmentBox[
       TagBox[
       "\[SelectionPlaceholder]", QuantumAlgebra`QuantumNotation`KetArgs, 
        BaseStyle -> "BraKetArg"], BoxBaselineShift -> 0], 
      QuantumAlgebra`QuantumNotation`UDScript, BaseStyle -> "RIndex"]], 
    QuantumAlgebra`BraKet, BaseStyle -> "BraKetWrapper"], "dbraket" -> TagBox[
    RowBox[{
      SubscriptBox["\[InvisiblePrefixScriptBase]", 
       TagBox[
        AdjustmentBox[
         TagBox[
         "\[SelectionPlaceholder]", QuantumAlgebra`QuantumNotation`BraArgs, 
          BaseStyle -> "BraKetArg"], BoxBaselineShift -> 0], 
        QuantumAlgebra`QuantumNotation`UDScript, BaseStyle -> "LIndex"]], 
      RowBox[{"\[LeftAngleBracket]", 
        AdjustmentBox[
         RowBox[{
           TagBox[
           "\[SelectionPlaceholder]", 
            QuantumAlgebra`QuantumNotation`BraKetArgs, BaseStyle -> 
            "BraKetArg"], "\[VerticalSeparator]", 
           TagBox[
           "\[SelectionPlaceholder]", 
            QuantumAlgebra`QuantumNotation`BraKetArgs, BaseStyle -> 
            "BraKetArg"]}], BoxBaselineShift -> 0], 
        "\[RightAngleBracket]"}]}], QuantumAlgebra`BraKet, BaseStyle -> 
    "BraKetWrapper"], "ubraket" -> TagBox[
    RowBox[{
      SuperscriptBox["\[InvisiblePrefixScriptBase]", 
       TagBox[
        AdjustmentBox[
         TagBox[
         "\[SelectionPlaceholder]", QuantumAlgebra`QuantumNotation`BraArgs, 
          BaseStyle -> "BraKetArg"], BoxBaselineShift -> 0], 
        QuantumAlgebra`QuantumNotation`UDScript, BaseStyle -> "LIndex"]], 
      RowBox[{"\[LeftAngleBracket]", 
        AdjustmentBox[
         RowBox[{
           TagBox[
           "\[SelectionPlaceholder]", 
            QuantumAlgebra`QuantumNotation`BraKetArgs, BaseStyle -> 
            "BraKetArg"], "\[VerticalSeparator]", 
           TagBox[
           "\[SelectionPlaceholder]", 
            QuantumAlgebra`QuantumNotation`BraKetArgs, BaseStyle -> 
            "BraKetArg"]}], BoxBaselineShift -> 0], 
        "\[RightAngleBracket]"}]}], QuantumAlgebra`BraKet, BaseStyle -> 
    "BraKetWrapper"], "dubraket" -> TagBox[
    RowBox[{
      SubsuperscriptBox["\[InvisiblePrefixScriptBase]", 
       TagBox[
        AdjustmentBox[
         TagBox[
         "\[SelectionPlaceholder]", QuantumAlgebra`QuantumNotation`BraArgs, 
          BaseStyle -> "BraKetArg"], BoxBaselineShift -> 0], 
        QuantumAlgebra`QuantumNotation`UDScript, BaseStyle -> "LIndex"], 
       TagBox[
        AdjustmentBox[
         TagBox[
         "\[SelectionPlaceholder]", QuantumAlgebra`QuantumNotation`BraArgs, 
          BaseStyle -> "BraKetArg"], BoxBaselineShift -> 0], 
        QuantumAlgebra`QuantumNotation`UDScript, BaseStyle -> "LIndex"]], 
      RowBox[{"\[LeftAngleBracket]", 
        AdjustmentBox[
         RowBox[{
           TagBox[
           "\[SelectionPlaceholder]", 
            QuantumAlgebra`QuantumNotation`BraKetArgs, BaseStyle -> 
            "BraKetArg"], "\[VerticalSeparator]", 
           TagBox[
           "\[SelectionPlaceholder]", 
            QuantumAlgebra`QuantumNotation`BraKetArgs, BaseStyle -> 
            "BraKetArg"]}], BoxBaselineShift -> 0], 
        "\[RightAngleBracket]"}]}], QuantumAlgebra`BraKet, BaseStyle -> 
    "BraKetWrapper"], "dbraketd" -> TagBox[
    RowBox[{
      SubscriptBox["\[InvisiblePrefixScriptBase]", 
       TagBox[
        AdjustmentBox[
         TagBox[
         "\[SelectionPlaceholder]", QuantumAlgebra`QuantumNotation`BraArgs, 
          BaseStyle -> "BraKetArg"], BoxBaselineShift -> 0], 
        QuantumAlgebra`QuantumNotation`UDScript, BaseStyle -> "LIndex"]], 
      SubscriptBox[
       RowBox[{"\[LeftAngleBracket]", 
         AdjustmentBox[
          RowBox[{
            TagBox[
            "\[SelectionPlaceholder]", 
             QuantumAlgebra`QuantumNotation`BraKetArgs, BaseStyle -> 
             "BraKetArg"], "\[VerticalSeparator]", 
            TagBox[
            "\[SelectionPlaceholder]", 
             QuantumAlgebra`QuantumNotation`BraKetArgs, BaseStyle -> 
             "BraKetArg"]}], BoxBaselineShift -> 0], "\[RightAngleBracket]"}], 
       TagBox[
        AdjustmentBox[
         TagBox[
         "\[SelectionPlaceholder]", QuantumAlgebra`QuantumNotation`BraArgs, 
          BaseStyle -> "BraKetArg"], BoxBaselineShift -> 0], 
        QuantumAlgebra`QuantumNotation`UDScript, BaseStyle -> "RIndex"]]}], 
    QuantumAlgebra`BraKet, BaseStyle -> "BraKetWrapper"], "dbraketu" -> TagBox[
    RowBox[{
      SubscriptBox["\[InvisiblePrefixScriptBase]", 
       TagBox[
        AdjustmentBox[
         TagBox[
         "\[SelectionPlaceholder]", QuantumAlgebra`QuantumNotation`BraArgs, 
          BaseStyle -> "BraKetArg"], BoxBaselineShift -> 0], 
        QuantumAlgebra`QuantumNotation`UDScript, BaseStyle -> "LIndex"]], 
      SuperscriptBox[
       RowBox[{"\[LeftAngleBracket]", 
         AdjustmentBox[
          RowBox[{
            TagBox[
            "\[SelectionPlaceholder]", 
             QuantumAlgebra`QuantumNotation`BraKetArgs, BaseStyle -> 
             "BraKetArg"], "\[VerticalSeparator]", 
            TagBox[
            "\[SelectionPlaceholder]", 
             QuantumAlgebra`QuantumNotation`BraKetArgs, BaseStyle -> 
             "BraKetArg"]}], BoxBaselineShift -> 0], "\[RightAngleBracket]"}], 
       TagBox[
        AdjustmentBox[
         TagBox[
         "\[SelectionPlaceholder]", QuantumAlgebra`QuantumNotation`BraArgs, 
          BaseStyle -> "BraKetArg"], BoxBaselineShift -> 0], 
        QuantumAlgebra`QuantumNotation`UDScript, BaseStyle -> "RIndex"]]}], 
    QuantumAlgebra`BraKet, BaseStyle -> "BraKetWrapper"], "dbraketdu" -> 
  TagBox[
    RowBox[{
      SubscriptBox["\[InvisiblePrefixScriptBase]", 
       TagBox[
        AdjustmentBox[
         TagBox[
         "\[SelectionPlaceholder]", QuantumAlgebra`QuantumNotation`BraArgs, 
          BaseStyle -> "BraKetArg"], BoxBaselineShift -> 0], 
        QuantumAlgebra`QuantumNotation`UDScript, BaseStyle -> "LIndex"]], 
      SubsuperscriptBox[
       RowBox[{"\[LeftAngleBracket]", 
         AdjustmentBox[
          RowBox[{
            TagBox[
            "\[SelectionPlaceholder]", 
             QuantumAlgebra`QuantumNotation`BraKetArgs, BaseStyle -> 
             "BraKetArg"], "\[VerticalSeparator]", 
            TagBox[
            "\[SelectionPlaceholder]", 
             QuantumAlgebra`QuantumNotation`BraKetArgs, BaseStyle -> 
             "BraKetArg"]}], BoxBaselineShift -> 0], "\[RightAngleBracket]"}], 
       TagBox[
        AdjustmentBox[
         TagBox[
         "\[SelectionPlaceholder]", QuantumAlgebra`QuantumNotation`BraArgs, 
          BaseStyle -> "BraKetArg"], BoxBaselineShift -> 0], 
        QuantumAlgebra`QuantumNotation`UDScript, BaseStyle -> "RIndex"], 
       TagBox[
        AdjustmentBox[
         TagBox[
         "\[SelectionPlaceholder]", QuantumAlgebra`QuantumNotation`BraArgs, 
          BaseStyle -> "BraKetArg"], BoxBaselineShift -> 0], 
        QuantumAlgebra`QuantumNotation`UDScript, BaseStyle -> "RIndex"]]}], 
    QuantumAlgebra`BraKet, BaseStyle -> "BraKetWrapper"], "ubraketd" -> TagBox[
    RowBox[{
      SuperscriptBox["\[InvisiblePrefixScriptBase]", 
       TagBox[
        AdjustmentBox[
         TagBox[
         "\[SelectionPlaceholder]", QuantumAlgebra`QuantumNotation`BraArgs, 
          BaseStyle -> "BraKetArg"], BoxBaselineShift -> 0], 
        QuantumAlgebra`QuantumNotation`UDScript, BaseStyle -> "LIndex"]], 
      SubscriptBox[
       RowBox[{"\[LeftAngleBracket]", 
         AdjustmentBox[
          RowBox[{
            TagBox[
            "\[SelectionPlaceholder]", 
             QuantumAlgebra`QuantumNotation`BraKetArgs, BaseStyle -> 
             "BraKetArg"], "\[VerticalSeparator]", 
            TagBox[
            "\[SelectionPlaceholder]", 
             QuantumAlgebra`QuantumNotation`BraKetArgs, BaseStyle -> 
             "BraKetArg"]}], BoxBaselineShift -> 0], "\[RightAngleBracket]"}], 
       TagBox[
        AdjustmentBox[
         TagBox[
         "\[SelectionPlaceholder]", QuantumAlgebra`QuantumNotation`BraArgs, 
          BaseStyle -> "BraKetArg"], BoxBaselineShift -> 0], 
        QuantumAlgebra`QuantumNotation`UDScript, BaseStyle -> "RIndex"]]}], 
    QuantumAlgebra`BraKet, BaseStyle -> "BraKetWrapper"], "ubraketu" -> TagBox[
    RowBox[{
      SuperscriptBox["\[InvisiblePrefixScriptBase]", 
       TagBox[
        AdjustmentBox[
         TagBox[
         "\[SelectionPlaceholder]", QuantumAlgebra`QuantumNotation`BraArgs, 
          BaseStyle -> "BraKetArg"], BoxBaselineShift -> 0], 
        QuantumAlgebra`QuantumNotation`UDScript, BaseStyle -> "LIndex"]], 
      SuperscriptBox[
       RowBox[{"\[LeftAngleBracket]", 
         AdjustmentBox[
          RowBox[{
            TagBox[
            "\[SelectionPlaceholder]", 
             QuantumAlgebra`QuantumNotation`BraKetArgs, BaseStyle -> 
             "BraKetArg"], "\[VerticalSeparator]", 
            TagBox[
            "\[SelectionPlaceholder]", 
             QuantumAlgebra`QuantumNotation`BraKetArgs, BaseStyle -> 
             "BraKetArg"]}], BoxBaselineShift -> 0], "\[RightAngleBracket]"}], 
       TagBox[
        AdjustmentBox[
         TagBox[
         "\[SelectionPlaceholder]", QuantumAlgebra`QuantumNotation`BraArgs, 
          BaseStyle -> "BraKetArg"], BoxBaselineShift -> 0], 
        QuantumAlgebra`QuantumNotation`UDScript, BaseStyle -> "RIndex"]]}], 
    QuantumAlgebra`BraKet, BaseStyle -> "BraKetWrapper"], "ubraketdu" -> 
  TagBox[
    RowBox[{
      SuperscriptBox["\[InvisiblePrefixScriptBase]", 
       TagBox[
        AdjustmentBox[
         TagBox[
         "\[SelectionPlaceholder]", QuantumAlgebra`QuantumNotation`BraArgs, 
          BaseStyle -> "BraKetArg"], BoxBaselineShift -> 0], 
        QuantumAlgebra`QuantumNotation`UDScript, BaseStyle -> "LIndex"]], 
      SubsuperscriptBox[
       RowBox[{"\[LeftAngleBracket]", 
         AdjustmentBox[
          RowBox[{
            TagBox[
            "\[SelectionPlaceholder]", 
             QuantumAlgebra`QuantumNotation`BraKetArgs, BaseStyle -> 
             "BraKetArg"], "\[VerticalSeparator]", 
            TagBox[
            "\[SelectionPlaceholder]", 
             QuantumAlgebra`QuantumNotation`BraKetArgs, BaseStyle -> 
             "BraKetArg"]}], BoxBaselineShift -> 0], "\[RightAngleBracket]"}], 
       TagBox[
        AdjustmentBox[
         TagBox[
         "\[SelectionPlaceholder]", QuantumAlgebra`QuantumNotation`BraArgs, 
          BaseStyle -> "BraKetArg"], BoxBaselineShift -> 0], 
        QuantumAlgebra`QuantumNotation`UDScript, BaseStyle -> "RIndex"], 
       TagBox[
        AdjustmentBox[
         TagBox[
         "\[SelectionPlaceholder]", QuantumAlgebra`QuantumNotation`BraArgs, 
          BaseStyle -> "BraKetArg"], BoxBaselineShift -> 0], 
        QuantumAlgebra`QuantumNotation`UDScript, BaseStyle -> "RIndex"]]}], 
    QuantumAlgebra`BraKet, BaseStyle -> "BraKetWrapper"], "dubraketd" -> 
  TagBox[
    RowBox[{
      SubsuperscriptBox["\[InvisiblePrefixScriptBase]", 
       TagBox[
        AdjustmentBox[
         TagBox[
         "\[SelectionPlaceholder]", QuantumAlgebra`QuantumNotation`BraArgs, 
          BaseStyle -> "BraKetArg"], BoxBaselineShift -> 0], 
        QuantumAlgebra`QuantumNotation`UDScript, BaseStyle -> "LIndex"], 
       TagBox[
        AdjustmentBox[
         TagBox[
         "\[SelectionPlaceholder]", QuantumAlgebra`QuantumNotation`BraArgs, 
          BaseStyle -> "BraKetArg"], BoxBaselineShift -> 0], 
        QuantumAlgebra`QuantumNotation`UDScript, BaseStyle -> "LIndex"]], 
      SubscriptBox[
       RowBox[{"\[LeftAngleBracket]", 
         AdjustmentBox[
          RowBox[{
            TagBox[
            "\[SelectionPlaceholder]", 
             QuantumAlgebra`QuantumNotation`BraKetArgs, BaseStyle -> 
             "BraKetArg"], "\[VerticalSeparator]", 
            TagBox[
            "\[SelectionPlaceholder]", 
             QuantumAlgebra`QuantumNotation`BraKetArgs, BaseStyle -> 
             "BraKetArg"]}], BoxBaselineShift -> 0], "\[RightAngleBracket]"}], 
       TagBox[
        AdjustmentBox[
         TagBox[
         "\[SelectionPlaceholder]", QuantumAlgebra`QuantumNotation`BraArgs, 
          BaseStyle -> "BraKetArg"], BoxBaselineShift -> 0], 
        QuantumAlgebra`QuantumNotation`UDScript, BaseStyle -> "RIndex"]]}], 
    QuantumAlgebra`BraKet, BaseStyle -> "BraKetWrapper"], "dubraketu" -> 
  TagBox[
    RowBox[{
      SubsuperscriptBox["\[InvisiblePrefixScriptBase]", 
       TagBox[
        AdjustmentBox[
         TagBox[
         "\[SelectionPlaceholder]", QuantumAlgebra`QuantumNotation`BraArgs, 
          BaseStyle -> "BraKetArg"], BoxBaselineShift -> 0], 
        QuantumAlgebra`QuantumNotation`UDScript, BaseStyle -> "LIndex"], 
       TagBox[
        AdjustmentBox[
         TagBox[
         "\[SelectionPlaceholder]", QuantumAlgebra`QuantumNotation`BraArgs, 
          BaseStyle -> "BraKetArg"], BoxBaselineShift -> 0], 
        QuantumAlgebra`QuantumNotation`UDScript, BaseStyle -> "LIndex"]], 
      SuperscriptBox[
       RowBox[{"\[LeftAngleBracket]", 
         AdjustmentBox[
          RowBox[{
            TagBox[
            "\[SelectionPlaceholder]", 
             QuantumAlgebra`QuantumNotation`BraKetArgs, BaseStyle -> 
             "BraKetArg"], "\[VerticalSeparator]", 
            TagBox[
            "\[SelectionPlaceholder]", 
             QuantumAlgebra`QuantumNotation`BraKetArgs, BaseStyle -> 
             "BraKetArg"]}], BoxBaselineShift -> 0], "\[RightAngleBracket]"}], 
       TagBox[
        AdjustmentBox[
         TagBox[
         "\[SelectionPlaceholder]", QuantumAlgebra`QuantumNotation`BraArgs, 
          BaseStyle -> "BraKetArg"], BoxBaselineShift -> 0], 
        QuantumAlgebra`QuantumNotation`UDScript, BaseStyle -> "RIndex"]]}], 
    QuantumAlgebra`BraKet, BaseStyle -> "BraKetWrapper"], "dubraketdu" -> 
  TagBox[
    RowBox[{
      SubsuperscriptBox["\[InvisiblePrefixScriptBase]", 
       TagBox[
        AdjustmentBox[
         TagBox[
         "\[SelectionPlaceholder]", QuantumAlgebra`QuantumNotation`BraArgs, 
          BaseStyle -> "BraKetArg"], BoxBaselineShift -> 0], 
        QuantumAlgebra`QuantumNotation`UDScript, BaseStyle -> "LIndex"], 
       TagBox[
        AdjustmentBox[
         TagBox[
         "\[SelectionPlaceholder]", QuantumAlgebra`QuantumNotation`BraArgs, 
          BaseStyle -> "BraKetArg"], BoxBaselineShift -> 0], 
        QuantumAlgebra`QuantumNotation`UDScript, BaseStyle -> "LIndex"]], 
      SubsuperscriptBox[
       RowBox[{"\[LeftAngleBracket]", 
         AdjustmentBox[
          RowBox[{
            TagBox[
            "\[SelectionPlaceholder]", 
             QuantumAlgebra`QuantumNotation`BraKetArgs, BaseStyle -> 
             "BraKetArg"], "\[VerticalSeparator]", 
            TagBox[
            "\[SelectionPlaceholder]", 
             QuantumAlgebra`QuantumNotation`BraKetArgs, BaseStyle -> 
             "BraKetArg"]}], BoxBaselineShift -> 0], "\[RightAngleBracket]"}], 
       TagBox[
        AdjustmentBox[
         TagBox[
         "\[SelectionPlaceholder]", QuantumAlgebra`QuantumNotation`BraArgs, 
          BaseStyle -> "BraKetArg"], BoxBaselineShift -> 0], 
        QuantumAlgebra`QuantumNotation`UDScript, BaseStyle -> "RIndex"], 
       TagBox[
        AdjustmentBox[
         TagBox[
         "\[SelectionPlaceholder]", QuantumAlgebra`QuantumNotation`BraArgs, 
          BaseStyle -> "BraKetArg"], BoxBaselineShift -> 0], 
        QuantumAlgebra`QuantumNotation`UDScript, BaseStyle -> "RIndex"]]}], 
    QuantumAlgebra`BraKet, BaseStyle -> "BraKetWrapper"], "sd" -> 
  SubscriptBox["\[Placeholder]", "\[Placeholder]"], "su" -> 
  SuperscriptBox["\[Placeholder]", "\[Placeholder]"], "sdu" -> 
  SubsuperscriptBox[
   "\[SelectionPlaceholder]", "\[SelectionPlaceholder]", 
    "\[SelectionPlaceholder]"]},
FrontEndVersion->"11.0 for Microsoft Windows (64-bit) (September 21, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 150, 2, 101, "Title"],
Cell[CellGroupData[{
Cell[755, 28, 103, 1, 70, "Section"],
Cell[CellGroupData[{
Cell[883, 33, 256, 5, 46, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[1164, 42, 2229, 37, 22, "Print"],
Cell[3396, 81, 2239, 38, 22, "Print"],
Cell[5638, 121, 2248, 38, 22, "Print"],
Cell[7889, 161, 2250, 38, 22, "Print"],
Cell[10142, 201, 2673, 43, 149, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[12876, 251, 93, 1, 70, "Section"],
Cell[CellGroupData[{
Cell[12994, 256, 333, 6, 30, "ItemNumbered"],
Cell[13330, 264, 317, 5, 30, "ItemNumbered"],
Cell[13650, 271, 302, 4, 30, "ItemNumbered"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[14001, 281, 94, 1, 70, "Section"],
Cell[14098, 284, 1600, 47, 87, "Input",
 InitializationCell->True],
Cell[15701, 333, 8666, 203, 526, "Input",
 InitializationCell->True],
Cell[24370, 538, 1430, 37, 48, "Input",
 InitializationCell->True],
Cell[25803, 577, 802, 21, 48, "Input",
 InitializationCell->True],
Cell[26608, 600, 817, 18, 66, "Input",
 InitializationCell->True],
Cell[27428, 620, 4051, 83, 220, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[31516, 708, 115, 1, 70, "Section"],
Cell[31634, 711, 3984, 104, 194, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[35643, 819, 99, 1, 49, "Subsection"],
Cell[35745, 822, 2389, 71, 145, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[38159, 897, 684, 11, 30, "Input"],
Cell[38846, 910, 459, 11, 50, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[39342, 926, 544, 9, 30, "Input"],
Cell[39889, 937, 3561, 92, 103, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[43499, 1035, 127, 1, 49, "Subsection"],
Cell[CellGroupData[{
Cell[43651, 1040, 114, 1, 39, "Subsubsection"],
Cell[43768, 1043, 224, 5, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[44029, 1053, 144, 2, 39, "Subsubsection"],
Cell[44176, 1057, 739, 14, 30, "Input"],
Cell[44918, 1073, 157, 4, 49, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[45112, 1082, 240, 3, 39, "Subsubsection"],
Cell[45355, 1087, 577, 12, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[45969, 1104, 221, 3, 39, "Subsubsection"],
Cell[46193, 1109, 784, 15, 30, "Input"],
Cell[46980, 1126, 360, 9, 30, "Input"],
Cell[47343, 1137, 155, 3, 30, "Text"],
Cell[47501, 1142, 523, 9, 68, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[48061, 1156, 264, 3, 39, "Subsubsection"],
Cell[48328, 1161, 1424, 23, 30, "Input"],
Cell[49755, 1186, 380, 9, 30, "Input"],
Cell[50138, 1197, 202, 5, 49, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[50377, 1207, 181, 2, 39, "Subsubsection"],
Cell[CellGroupData[{
Cell[50583, 1213, 1845, 33, 69, "Input"],
Cell[52431, 1248, 3264, 89, 87, "Output"]
}, Open  ]],
Cell[55710, 1340, 219, 5, 49, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[55978, 1351, 98, 1, 49, "Subsection"],
Cell[56079, 1354, 1190, 33, 86, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[57294, 1391, 697, 14, 30, "Input"],
Cell[57994, 1407, 8330, 223, 172, "Output"]
}, Open  ]],
Cell[66339, 1633, 501, 8, 68, "Text"]
}, Open  ]],
Cell[66855, 1644, 97, 1, 49, "Subsection"]
}, Open  ]]
}, Open  ]]
}
]
*)

