(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     17171,        529]
NotebookOptionsPosition[     10570,        351]
NotebookOutlinePosition[     14254,        433]
CellTagsIndexPosition[     14211,        430]
WindowTitle->Quantum Algebra Packages
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[GridBox[{
   {Cell["QUANTUM ALGEBRA PACKAGE GUIDE", "PacletNameCell"], Cell[TextData[{
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "Related Guides",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"Related Guides", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->False], {"\<\"Quantum Algebra Overview\"\>":>
       Documentation`HelpLookup[
       "paclet:QuantumAlgebra/guide/Contents"], "\<\"Quantum Algebra \
Guide\"\>":>Documentation`HelpLookup[
       "paclet:QuantumAlgebra/guide/Guide"], "\<\"Input Aliases\"\>":>
       Documentation`HelpLookup["paclet:QuantumAlgebra/guide/InputAliases"]},
       Appearance->None,
       MenuAppearance->Automatic,
       MenuStyle->"GuideMoreAbout"]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "Tutorials",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"Tutorials", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->False], {"\<\"Quantum Algebra Basics\"\>":>
       Documentation`HelpLookup["paclet:QuantumAlgebra/tutorial/Basics"]},
       Appearance->None,
       MenuAppearance->Automatic,
       MenuStyle->"GuideTutorial"]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "URL",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"URL", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->False], {"\<\"QuantumAlgebra/guide/Packages\"\>":>
       None, "\<\"Copy Wolfram Documentation Center URL\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell["QuantumAlgebra/guide/Packages"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; Null], 
       Delimiter, "\<\"Copy web URL\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell[
              BoxData[
               MakeBoxes[
                Hyperlink[
                "http://reference.wolfram.com/language/QuantumAlgebra/guide/\
Packages.html"], StandardForm]], "Input", TextClipboardType -> "PlainText"]}, 
            Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; 
        Null], "\<\"Go to web URL\"\>":>FrontEndExecute[{
         NotebookLocate[{
           URL[
            StringJoin[
             If[
              TrueQ[DocumentationBuild`Make`Private`wsmlinkQ$6517], 
              "http://reference.wolfram.com/system-modeler/", 
              "http://reference.wolfram.com/language/"], 
             "QuantumAlgebra/guide/Packages", ".html"]], None}]}]},
       Appearance->None,
       MenuAppearance->Automatic,
       MenuStyle->"URLMenu"]],
      LineSpacing->{1.4, 0}]
    }], "AnchorBar"]}
  }]], "AnchorBarGrid",
 CellID->1],

Cell[CellGroupData[{

Cell["Quantum Algebra Packages", "GuideTitle",
 CellID->942062912],

Cell["\<\
This guide page gives an overview about the modules in the Quantum Algebra \
package and their content.\
\>", "GuideAbstract",
 CellID->2001916300],

Cell[CellGroupData[{

Cell["QuantumAlgebra.m", "GuideFunctionsSubsection",
 CellID->168525014],

Cell["\<\
This is the main module of the package and the only one in the original \
package. 
It contains the Algebra rules for Quantum Algebra, i.e. how the basic Quantum \
objects behave and are simplified in calculations. A few helper functions \
help decide what type of basic Quantum object an expression is.
This release of the Quantum Algebra package contains a few improvements via \
the original package: the decision about the type of Quantum object is \
improved and more detailed, a few bugs are fixed and a new type of constant - \
called Complex Constant - has been introduced to permit further \
simplification of Quantum expressions.\
\>", "GuideText",
 CellID->165460465],

Cell["\t", "GuideDelimiterSubsection",
 CellID->22563968]
}, Open  ]],

Cell[CellGroupData[{

Cell["Agreements.m", "GuideFunctionsSubsection",
 CellID->559035606],

Cell["\<\
Contains definitions like Replacement Rules, Explicit Integration Variables, \
Time Constraint, Assumptions, Index Character and Not Scripted Variables. \
Also contains supporting functions like functions to define or query such \
definitions.
Examples are QAAddAssumptions and QAGetAssumptions.\
\>", "GuideText",
 CellID->367654504],

Cell["\t", "GuideDelimiterSubsection",
 CellID->34982422]
}, Open  ]],

Cell[CellGroupData[{

Cell["Analyze.m", "GuideFunctionsSubsection",
 CellID->410453794],

Cell["\<\
Contains checks for Quantum types like Ket, Bra, BraKet, Operator, \
SimpleConstant and QuantumConstant. They permit a detailed check, if an \
expression is a supported Quantum object.\
\>", "GuideText",
 CellID->33873020],

Cell["\t", "GuideDelimiterSubsection",
 CellID->6369384]
}, Open  ]],

Cell[CellGroupData[{

Cell["Constants.m", "GuideFunctionsSubsection",
 CellID->182378492],

Cell["\<\
Contains the definitions for the Pauli Matrices and the Dirac Matrices.\
\>", "GuideText",
 CellID->40964215],

Cell["\t", "GuideDelimiterSubsection",
 CellID->78223406]
}, Open  ]],

Cell[CellGroupData[{

Cell["Derivation.m", "GuideFunctionsSubsection",
 CellID->630469000],

Cell["\<\
Incomplete and to be completed in future versions of this application.\
\>", "GuideText",
 CellID->311050153],

Cell["\t", "GuideDelimiterSubsection",
 CellID->24673360]
}, Open  ]],

Cell[CellGroupData[{

Cell["DifferentialOperators.m", "GuideFunctionsSubsection",
 CellID->54806046],

Cell["\<\
Contains a few operator definitions. They are seldom used, but to study their \
usage please refer to sample notebook Dirac Equation.\
\>", "GuideText",
 CellID->436978132],

Cell["\t", "GuideDelimiterSubsection",
 CellID->219704609]
}, Open  ]],

Cell[CellGroupData[{

Cell["Options.m", "GuideFunctionsSubsection",
 CellID->306482911],

Cell["\<\
Supports some options for the package. There are 4 options for printout \
control of diagnostic prints and 1 option to control the system of Quantum \
types (DefinitionLevel).
Also the diagnostic print function QAPrint, the function QASniff and QATiming \
are contained.\
\>", "GuideText",
 CellID->174454626],

Cell["\t", "GuideDelimiterSubsection",
 CellID->662756017]
}, Open  ]],

Cell[CellGroupData[{

Cell["QuantumNotation.m", "GuideFunctionsSubsection",
 CellID->6375819],

Cell["\<\
Contains functions for the definition of Notations, Input Aliases, Boxes. \
They allow proper display of Quantum objects and 2-dimensional input.
This module replaces a definition Notebook (QANotations.nb) in the original \
package.\
\>", "GuideText",
 CellID->38417311],

Cell["\t", "GuideDelimiterSubsection",
 CellID->120466818]
}, Open  ]],

Cell[CellGroupData[{

Cell["RulesSupplement.m", "GuideFunctionsSubsection",
 CellID->326883590],

Cell["\<\
Contains a supplement of the original package. It deals with Operator \
manipulation, integration, summation, derivation as they are performed in QFT \
(Quantum Field Theory) in symbolical form.\
\>", "GuideText",
 CellID->1006578357],

Cell["\t", "GuideDelimiterSubsection",
 CellID->732978]
}, Open  ]],

Cell[CellGroupData[{

Cell["Styles.m", "GuideFunctionsSubsection",
 CellID->103788340],

Cell["\<\
Contains functions for the definition of Notebook styles. These styles \
control the proper display of Quantum objects in Notebooks and in the \
documentation.
This is a partial replacement of the original definition Notebook \
(QANotations.nb)\
\>", "GuideText",
 CellID->710547200]
}, Open  ]],

Cell["", "SectionFooterSpacer"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  InterpretationBox[
   StyleBox[
    GraphicsBox[{},
     BaselinePosition->Baseline,
     ImageSize->{6, 0}],
    CacheGraphics->False],
   Spacer[6]]]],
 "Related Guides"
}], "GuideMoreAboutSection",
 WholeCellGroupOpener->True,
 CellID->23220180],

Cell["", "SectionHeaderSpacer"],

Cell[BoxData[{
 TemplateBox[{Cell[
    TextData["Quantum Algebra Overview"]],
   "paclet:QuantumAlgebra/guide/Contents"},
  "RefLink",
  BaseStyle->"GuideMoreAbout"], "\n", 
 RowBox[{" ", 
  RowBox[{
   RowBox[{"-", " ", "Overview"}], " ", "page", " ", "with", " ", "links", 
   " ", "to", " ", "all", " ", "documentation", " ", 
   "pages"}]}]}], "GuideMoreAbout",
 CellID->1885805579],

Cell[BoxData[{
 TemplateBox[{Cell[
    TextData["Quantum Algebra Guide"]],"paclet:QuantumAlgebra/guide/Guide"},
  "RefLink",
  BaseStyle->"GuideMoreAbout"], "\n", 
 RowBox[{" ", 
  RowBox[{
   RowBox[{"-", " ", "Basic"}], " ", "guide"}]}]}], "GuideMoreAbout",
 CellID->116065012],

Cell[BoxData[{
 TemplateBox[{Cell[
    TextData["Input Aliases"]],"paclet:QuantumAlgebra/guide/InputAliases"},
  "RefLink",
  BaseStyle->"GuideMoreAbout"], "\n", 
 RowBox[{" ", 
  RowBox[{
   RowBox[{"-", " ", "Overview"}], " ", "over", " ", "input", " ", "with", 
   " ", "aliases"}]}]}], "GuideMoreAbout",
 CellID->252299663]
}, Open  ]],

Cell[" ", "FooterCell"]
},
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{725, 750},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
WindowTitle->"Quantum Algebra Packages",
TaggingRules->{
 "ModificationHighlight" -> False, "ColorType" -> "GuideColor", "LinkTrails" -> 
  GridBox[{{
      RowBox[{
        ButtonBox[
        "Mathematica", ButtonData -> 
         "paclet:QuantumAlgebra/guide/QuantumAlgebra", 
         BaseStyle -> {"Link", "DockedLinkTrail"}]}]}}, ColumnAlignments -> 
    Left], "ExampleCounter" -> 1, "NeedPlatMsgIn" -> None, "RootCaptions" -> 
  "", "Metadata" -> {
   "built" -> "{2020, 4, 28, 10, 3, 28.7681452}", 
    "history" -> {"1.0.0", "2.1.2", "", ""}, "context" -> "QuantumAlgebra`", 
    "keywords" -> {}, "specialkeywords" -> {}, 
    "tutorialcollectionlinks" -> {}, "index" -> True, "label" -> 
    "Quantum Algebra Package Guide", "language" -> "en", "paclet" -> 
    "QuantumAlgebra Package", "status" -> "None", "summary" -> 
    "This guide page gives an overview about the modules in the Quantum \
Algebra package and their content.", "synonyms" -> {}, "tabletags" -> 
    DocumentationBuild`Make`Private`tabletaggingrules$6350, "title" -> 
    "Quantum Algebra Packages", "titlemodifier" -> "", "windowtitle" -> 
    "Quantum Algebra Packages", "type" -> "Guide", "uri" -> 
    "QuantumAlgebra/guide/Packages"}, "SearchTextTranslated" -> ""},
FrontEndVersion->"11.0 for Microsoft Windows (64-bit) (September 21, 2016)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[
    StyleDefinitions -> 
     FrontEnd`FileName[{"Wolfram"}, "Reference.nb", CharacterEncoding -> 
       "UTF-8"]]], 
   Cell["Bra Ket Styles", "Section"], 
   Cell[" The cells below define certain styles needed for defining \
Bras&Kets.These styles serve to give the correct structural properties to \
Bras & Kets ", "Text"], 
   Cell[
    StyleData["BraKetArg"], SpanMinSize -> Automatic, StyleMenuListing -> 
    None, AdjustmentBoxOptions -> {BoxMargins -> {{0, 0}, {0, 0}}}, 
    TagBoxOptions -> {Editable -> True, Selectable -> True}, 
    AutoStyleOptions -> {"UnmatchedBracketStyle" -> "UnmatchedBracket"}], 
   Cell[
    StyleData["BraWrapper"], ScriptBaselineShifts -> {0.6, 0.9}, SpanMinSize -> 
    2, StyleMenuListing -> None, 
    AdjustmentBoxOptions -> {BoxMargins -> {{0.2, -0.13}, {0, 0}}}, 
    TagBoxOptions -> {Editable -> False}, 
    AutoStyleOptions -> {"UnmatchedBracketStyle" -> None}], 
   Cell[
    StyleData["KetWrapper"], ScriptBaselineShifts -> {0.6, 0.9}, SpanMinSize -> 
    2, StyleMenuListing -> None, 
    AdjustmentBoxOptions -> {BoxMargins -> {{-0.1, 0.2}, {0, 0}}}, 
    TagBoxOptions -> {Editable -> False}, 
    AutoStyleOptions -> {"UnmatchedBracketStyle" -> None}], 
   Cell[
    StyleData["BraKetWrapper"], ScriptBaselineShifts -> {0.6, 0.9}, 
    SpanMinSize -> 2, StyleMenuListing -> None, 
    AdjustmentBoxOptions -> {BoxMargins -> {{0.25, 0.25}, {0, 0}}}, 
    TagBoxOptions -> {Editable -> False}, 
    AutoStyleOptions -> {"UnmatchedBracketStyle" -> None}], 
   Cell[
    StyleData["RIndex"], StyleMenuListing -> None, 
    AdjustmentBoxOptions -> {BoxMargins -> {{-0.16, 0}, {0, 0}}}, 
    TagBoxOptions -> {Editable -> False}], 
   Cell[
    StyleData["LIndex"], StyleMenuListing -> None, 
    AdjustmentBoxOptions -> {BoxMargins -> {{0, -0.1}, {0, 0}}}, 
    TagBoxOptions -> {Editable -> False}]}, Visible -> False, FrontEndVersion -> 
  "11.0 for Microsoft Windows (64-bit) (September 21, 2016)", 
  StyleDefinitions -> "PrivateStylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[596, 21, 3843, 93, 50, "AnchorBarGrid",
 CellID->1],
Cell[CellGroupData[{
Cell[4464, 118, 66, 1, 47, "GuideTitle",
 CellID->942062912],
Cell[4533, 121, 157, 4, 48, "GuideAbstract",
 CellID->2001916300],
Cell[CellGroupData[{
Cell[4715, 129, 72, 1, 30, "GuideFunctionsSubsection",
 CellID->168525014],
Cell[4790, 132, 688, 12, 137, "GuideText",
 CellID->165460465],
Cell[5481, 146, 57, 1, 21, "GuideDelimiterSubsection",
 CellID->22563968]
}, Open  ]],
Cell[CellGroupData[{
Cell[5575, 152, 68, 1, 30, "GuideFunctionsSubsection",
 CellID->559035606],
Cell[5646, 155, 344, 7, 72, "GuideText",
 CellID->367654504],
Cell[5993, 164, 57, 1, 21, "GuideDelimiterSubsection",
 CellID->34982422]
}, Open  ]],
Cell[CellGroupData[{
Cell[6087, 170, 65, 1, 30, "GuideFunctionsSubsection",
 CellID->410453794],
Cell[6155, 173, 232, 5, 34, "GuideText",
 CellID->33873020],
Cell[6390, 180, 56, 1, 21, "GuideDelimiterSubsection",
 CellID->6369384]
}, Open  ]],
Cell[CellGroupData[{
Cell[6483, 186, 67, 1, 30, "GuideFunctionsSubsection",
 CellID->182378492],
Cell[6553, 189, 119, 3, 20, "GuideText",
 CellID->40964215],
Cell[6675, 194, 57, 1, 21, "GuideDelimiterSubsection",
 CellID->78223406]
}, Open  ]],
Cell[CellGroupData[{
Cell[6769, 200, 68, 1, 30, "GuideFunctionsSubsection",
 CellID->630469000],
Cell[6840, 203, 119, 3, 20, "GuideText",
 CellID->311050153],
Cell[6962, 208, 57, 1, 21, "GuideDelimiterSubsection",
 CellID->24673360]
}, Open  ]],
Cell[CellGroupData[{
Cell[7056, 214, 78, 1, 30, "GuideFunctionsSubsection",
 CellID->54806046],
Cell[7137, 217, 182, 4, 34, "GuideText",
 CellID->436978132],
Cell[7322, 223, 58, 1, 70, "GuideDelimiterSubsection",
 CellID->219704609]
}, Open  ]],
Cell[CellGroupData[{
Cell[7417, 229, 65, 1, 70, "GuideFunctionsSubsection",
 CellID->306482911],
Cell[7485, 232, 319, 7, 70, "GuideText",
 CellID->174454626],
Cell[7807, 241, 58, 1, 70, "GuideDelimiterSubsection",
 CellID->662756017]
}, Open  ]],
Cell[CellGroupData[{
Cell[7902, 247, 71, 1, 70, "GuideFunctionsSubsection",
 CellID->6375819],
Cell[7976, 250, 280, 6, 70, "GuideText",
 CellID->38417311],
Cell[8259, 258, 58, 1, 70, "GuideDelimiterSubsection",
 CellID->120466818]
}, Open  ]],
Cell[CellGroupData[{
Cell[8354, 264, 73, 1, 70, "GuideFunctionsSubsection",
 CellID->326883590],
Cell[8430, 267, 244, 5, 70, "GuideText",
 CellID->1006578357],
Cell[8677, 274, 55, 1, 70, "GuideDelimiterSubsection",
 CellID->732978]
}, Open  ]],
Cell[CellGroupData[{
Cell[8769, 280, 64, 1, 70, "GuideFunctionsSubsection",
 CellID->103788340],
Cell[8836, 283, 293, 7, 70, "GuideText",
 CellID->710547200]
}, Open  ]],
Cell[9144, 293, 31, 0, 70, "SectionFooterSpacer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9212, 298, 281, 12, 70, "GuideMoreAboutSection",
 CellID->23220180],
Cell[9496, 312, 31, 0, 70, "SectionHeaderSpacer"],
Cell[9530, 314, 386, 11, 70, "GuideMoreAbout",
 CellID->1885805579],
Cell[9919, 327, 279, 8, 70, "GuideMoreAbout",
 CellID->116065012],
Cell[10201, 337, 327, 9, 70, "GuideMoreAbout",
 CellID->252299663]
}, Open  ]],
Cell[10543, 349, 23, 0, 70, "FooterCell"]
}
]
*)

